# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: testpb/bank.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.orm.v1 import orm_pb2 as cosmos_dot_orm_dot_v1_dot_orm__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11testpb/bank.proto\x12\x06testpb\x1a\x17\x63osmos/orm/v1/orm.proto\"_\n\x07\x42\x61lance\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04:$\xf2\x9e\xd3\x8e\x03\x1e\n\x0f\n\raddress,denom\x12\t\n\x05\x64\x65nom\x10\x01\x18\x01\":\n\x06Supply\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04:\x11\xf2\x9e\xd3\x8e\x03\x0b\n\x07\n\x05\x64\x65nom\x18\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'testpb.bank_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BALANCE._options = None
  _BALANCE._serialized_options = b'\362\236\323\216\003\036\n\017\n\raddress,denom\022\t\n\005denom\020\001\030\001'
  _SUPPLY._options = None
  _SUPPLY._serialized_options = b'\362\236\323\216\003\013\n\007\n\005denom\030\002'
  _globals['_BALANCE']._serialized_start=54
  _globals['_BALANCE']._serialized_end=149
  _globals['_SUPPLY']._serialized_start=151
  _globals['_SUPPLY']._serialized_end=209
# @@protoc_insertion_point(module_scope)
