# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/exchange/v1beta1/tx.proto\x12\x1ainjective.exchange.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a.cosmos/distribution/v1beta1/distribution.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a)injective/exchange/v1beta1/exchange.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x88\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32\".injective.exchange.v1beta1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse\"y\n\nMsgDeposit\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x14\n\x12MsgDepositResponse\"z\n\x0bMsgWithdraw\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x15\n\x13MsgWithdrawResponse\"z\n\x17MsgCreateSpotLimitOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12:\n\x05order\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x00:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"?\n\x1fMsgCreateSpotLimitOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x81\x01\n\x1dMsgBatchCreateSpotLimitOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12;\n\x06orders\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x00:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"G\n%MsgBatchCreateSpotLimitOrdersResponse\x12\x14\n\x0corder_hashes\x18\x01 \x03(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x97\x02\n\x1aMsgInstantSpotMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x12\n\nbase_denom\x18\x03 \x01(\t\x12\x13\n\x0bquote_denom\x18\x04 \x01(\t\x12K\n\x13min_price_tick_size\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\x06 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"$\n\"MsgInstantSpotMarketLaunchResponse\"\xbb\x05\n\x1fMsgInstantPerpetualMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x13\n\x0boracle_base\x18\x04 \x01(\t\x12\x14\n\x0coracle_quote\x18\x05 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x06 \x01(\r\x12\x39\n\x0boracle_type\x18\x07 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x46\n\x0emaker_fee_rate\x18\x08 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0etaker_fee_rate\x18\t \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12L\n\x14initial_margin_ratio\x18\n \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12P\n\x18maintenance_margin_ratio\x18\x0b \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12K\n\x13min_price_tick_size\x18\x0c \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\r \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\")\n\'MsgInstantPerpetualMarketLaunchResponse\"\xef\x04\n#MsgInstantBinaryOptionsMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x15\n\roracle_symbol\x18\x03 \x01(\t\x12\x17\n\x0foracle_provider\x18\x04 \x01(\t\x12\x39\n\x0boracle_type\x18\x05 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x06 \x01(\r\x12\x46\n\x0emaker_fee_rate\x18\x07 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0etaker_fee_rate\x18\x08 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x1c\n\x14\x65xpiration_timestamp\x18\t \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\n \x01(\x03\x12\r\n\x05\x61\x64min\x18\x0b \x01(\t\x12\x13\n\x0bquote_denom\x18\x0c \x01(\t\x12K\n\x13min_price_tick_size\x18\r \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\x0e \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"-\n+MsgInstantBinaryOptionsMarketLaunchResponse\"\xcf\x05\n#MsgInstantExpiryFuturesMarketLaunch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x13\n\x0boracle_base\x18\x04 \x01(\t\x12\x14\n\x0coracle_quote\x18\x05 \x01(\t\x12\x39\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x0e\n\x06\x65xpiry\x18\x08 \x01(\x03\x12\x46\n\x0emaker_fee_rate\x18\t \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0etaker_fee_rate\x18\n \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12L\n\x14initial_margin_ratio\x18\x0b \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12P\n\x18maintenance_margin_ratio\x18\x0c \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12K\n\x13min_price_tick_size\x18\r \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\x0e \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"-\n+MsgInstantExpiryFuturesMarketLaunchResponse\"{\n\x18MsgCreateSpotMarketOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12:\n\x05order\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x00:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x8b\x01\n MsgCreateSpotMarketOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12I\n\x07results\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.SpotMarketOrderResultsB\x04\xc8\xde\x1f\x01:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xe0\x01\n\x16SpotMarketOrderResults\x12@\n\x08quantity\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12=\n\x05price\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12;\n\x03\x66\x65\x65\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x82\x01\n\x1dMsgCreateDerivativeLimitOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"E\n%MsgCreateDerivativeLimitOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x85\x01\n MsgCreateBinaryOptionsLimitOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"H\n(MsgCreateBinaryOptionsLimitOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x89\x01\n#MsgBatchCreateDerivativeLimitOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x41\n\x06orders\x18\x02 \x03(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"M\n+MsgBatchCreateDerivativeLimitOrdersResponse\x12\x14\n\x0corder_hashes\x18\x01 \x03(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x80\x01\n\x12MsgCancelSpotOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x12\n\norder_hash\x18\x04 \x01(\t\x12\x0b\n\x03\x63id\x18\x05 \x01(\t:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x1c\n\x1aMsgCancelSpotOrderResponse\"v\n\x18MsgBatchCancelSpotOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x00:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"=\n MsgBatchCancelSpotOrdersResponse\x12\x0f\n\x07success\x18\x01 \x03(\x08:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x7f\n!MsgBatchCancelBinaryOptionsOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x00:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"F\n)MsgBatchCancelBinaryOptionsOrdersResponse\x12\x0f\n\x07success\x18\x01 \x03(\x08:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xc7\x05\n\x14MsgBatchUpdateOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12%\n\x1dspot_market_ids_to_cancel_all\x18\x03 \x03(\t\x12+\n#derivative_market_ids_to_cancel_all\x18\x04 \x03(\t\x12J\n\x15spot_orders_to_cancel\x18\x05 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x01\x12P\n\x1b\x64\x65rivative_orders_to_cancel\x18\x06 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x01\x12J\n\x15spot_orders_to_create\x18\x07 \x03(\x0b\x32%.injective.exchange.v1beta1.SpotOrderB\x04\xc8\xde\x1f\x01\x12V\n\x1b\x64\x65rivative_orders_to_create\x18\x08 \x03(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x01\x12T\n\x1f\x62inary_options_orders_to_cancel\x18\t \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x01\x12/\n\'binary_options_market_ids_to_cancel_all\x18\n \x03(\t\x12Z\n\x1f\x62inary_options_orders_to_create\x18\x0b \x03(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x01:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\xf0\x01\n\x1cMsgBatchUpdateOrdersResponse\x12\x1b\n\x13spot_cancel_success\x18\x01 \x03(\x08\x12!\n\x19\x64\x65rivative_cancel_success\x18\x02 \x03(\x08\x12\x19\n\x11spot_order_hashes\x18\x03 \x03(\t\x12\x1f\n\x17\x64\x65rivative_order_hashes\x18\x04 \x03(\t\x12%\n\x1d\x62inary_options_cancel_success\x18\x05 \x03(\x08\x12#\n\x1b\x62inary_options_order_hashes\x18\x06 \x03(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x83\x01\n\x1eMsgCreateDerivativeMarketOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x97\x01\n&MsgCreateDerivativeMarketOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12O\n\x07results\x18\x02 \x01(\x0b\x32\x38.injective.exchange.v1beta1.DerivativeMarketOrderResultsB\x04\xc8\xde\x1f\x01:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xef\x02\n\x1c\x44\x65rivativeMarketOrderResults\x12@\n\x08quantity\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12=\n\x05price\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12;\n\x03\x66\x65\x65\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12G\n\x0eposition_delta\x18\x04 \x01(\x0b\x32).injective.exchange.v1beta1.PositionDeltaB\x04\xc8\xde\x1f\x00\x12>\n\x06payout\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x86\x01\n!MsgCreateBinaryOptionsMarketOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12@\n\x05order\x18\x02 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x00:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x9a\x01\n)MsgCreateBinaryOptionsMarketOrderResponse\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12O\n\x07results\x18\x02 \x01(\x0b\x32\x38.injective.exchange.v1beta1.DerivativeMarketOrderResultsB\x04\xc8\xde\x1f\x01:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x9a\x01\n\x18MsgCancelDerivativeOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x12\n\norder_hash\x18\x04 \x01(\t\x12\x12\n\norder_mask\x18\x05 \x01(\x05\x12\x0b\n\x03\x63id\x18\x06 \x01(\t:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\"\n MsgCancelDerivativeOrderResponse\"\x9d\x01\n\x1bMsgCancelBinaryOptionsOrder\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x12\n\norder_hash\x18\x04 \x01(\t\x12\x12\n\norder_mask\x18\x05 \x01(\x05\x12\x0b\n\x03\x63id\x18\x06 \x01(\t:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"%\n#MsgCancelBinaryOptionsOrderResponse\"j\n\tOrderData\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x12\n\norder_hash\x18\x03 \x01(\t\x12\x12\n\norder_mask\x18\x04 \x01(\x05\x12\x0b\n\x03\x63id\x18\x05 \x01(\t\"|\n\x1eMsgBatchCancelDerivativeOrders\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32%.injective.exchange.v1beta1.OrderDataB\x04\xc8\xde\x1f\x00:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"C\n&MsgBatchCancelDerivativeOrdersResponse\x12\x0f\n\x07success\x18\x01 \x03(\x08:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xa6\x01\n\x15MsgSubaccountTransfer\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1c\n\x14source_subaccount_id\x18\x02 \x01(\t\x12!\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\t\x12/\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x0b\x82\xe7\xb0*\x06sender\"\x1f\n\x1dMsgSubaccountTransferResponse\"\xa4\x01\n\x13MsgExternalTransfer\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1c\n\x14source_subaccount_id\x18\x02 \x01(\t\x12!\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\t\x12/\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x0b\x82\xe7\xb0*\x06sender\"\x1d\n\x1bMsgExternalTransferResponse\"\x9f\x01\n\x14MsgLiquidatePosition\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12@\n\x05order\x18\x04 \x01(\x0b\x32+.injective.exchange.v1beta1.DerivativeOrderB\x04\xc8\xde\x1f\x01:\x0b\x82\xe7\xb0*\x06sender\"\x1e\n\x1cMsgLiquidatePositionResponse\"\xcc\x01\n\x19MsgIncreasePositionMargin\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1c\n\x14source_subaccount_id\x18\x02 \x01(\t\x12!\n\x19\x64\x65stination_subaccount_id\x18\x03 \x01(\t\x12\x11\n\tmarket_id\x18\x04 \x01(\t\x12>\n\x06\x61mount\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:\x0b\x82\xe7\xb0*\x06sender\"#\n!MsgIncreasePositionMarginResponse\"z\n\x1cMsgPrivilegedExecuteContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\r\n\x05\x66unds\x18\x02 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x9c\x01\n$MsgPrivilegedExecuteContractResponse\x12_\n\nfunds_diff\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\"\n\x10MsgRewardsOptOut\x12\x0e\n\x06sender\x18\x01 \x01(\t\"\x1a\n\x18MsgRewardsOptOutResponse\"d\n\x15MsgReclaimLockedFunds\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x1b\n\x13lockedAccountPubKey\x18\x02 \x01(\x0c\x12\x11\n\tsignature\x18\x03 \x01(\x0c:\x0b\x82\xe7\xb0*\x06sender\"\x1f\n\x1dMsgReclaimLockedFundsResponse\"r\n\x0bMsgSignData\x12K\n\x06Signer\x18\x01 \x01(\x0c\x42;\xea\xde\x1f\x06signer\xfa\xde\x1f-github.com/cosmos/cosmos-sdk/types.AccAddress\x12\x16\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x42\x08\xea\xde\x1f\x04\x64\x61ta\"g\n\nMsgSignDoc\x12\x1b\n\tsign_type\x18\x01 \x01(\tB\x08\xea\xde\x1f\x04type\x12<\n\x05value\x18\x02 \x01(\x0b\x32\'.injective.exchange.v1beta1.MsgSignDataB\x04\xc8\xde\x1f\x00\"\x93\x02\n!MsgAdminUpdateBinaryOptionsMarket\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12H\n\x10settlement_price\x18\x03 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x1c\n\x14\x65xpiration_timestamp\x18\x04 \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\x05 \x01(\x03\x12\x38\n\x06status\x18\x06 \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus:\x0b\x82\xe7\xb0*\x06sender\"+\n)MsgAdminUpdateBinaryOptionsMarketResponse2\x90\"\n\x03Msg\x12\x61\n\x07\x44\x65posit\x12&.injective.exchange.v1beta1.MsgDeposit\x1a..injective.exchange.v1beta1.MsgDepositResponse\x12\x64\n\x08Withdraw\x12\'.injective.exchange.v1beta1.MsgWithdraw\x1a/.injective.exchange.v1beta1.MsgWithdrawResponse\x12\x91\x01\n\x17InstantSpotMarketLaunch\x12\x36.injective.exchange.v1beta1.MsgInstantSpotMarketLaunch\x1a>.injective.exchange.v1beta1.MsgInstantSpotMarketLaunchResponse\x12\xa0\x01\n\x1cInstantPerpetualMarketLaunch\x12;.injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunch\x1a\x43.injective.exchange.v1beta1.MsgInstantPerpetualMarketLaunchResponse\x12\xac\x01\n InstantExpiryFuturesMarketLaunch\x12?.injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunch\x1aG.injective.exchange.v1beta1.MsgInstantExpiryFuturesMarketLaunchResponse\x12\x88\x01\n\x14\x43reateSpotLimitOrder\x12\x33.injective.exchange.v1beta1.MsgCreateSpotLimitOrder\x1a;.injective.exchange.v1beta1.MsgCreateSpotLimitOrderResponse\x12\x9a\x01\n\x1a\x42\x61tchCreateSpotLimitOrders\x12\x39.injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrders\x1a\x41.injective.exchange.v1beta1.MsgBatchCreateSpotLimitOrdersResponse\x12\x8b\x01\n\x15\x43reateSpotMarketOrder\x12\x34.injective.exchange.v1beta1.MsgCreateSpotMarketOrder\x1a<.injective.exchange.v1beta1.MsgCreateSpotMarketOrderResponse\x12y\n\x0f\x43\x61ncelSpotOrder\x12..injective.exchange.v1beta1.MsgCancelSpotOrder\x1a\x36.injective.exchange.v1beta1.MsgCancelSpotOrderResponse\x12\x8b\x01\n\x15\x42\x61tchCancelSpotOrders\x12\x34.injective.exchange.v1beta1.MsgBatchCancelSpotOrders\x1a<.injective.exchange.v1beta1.MsgBatchCancelSpotOrdersResponse\x12\x7f\n\x11\x42\x61tchUpdateOrders\x12\x30.injective.exchange.v1beta1.MsgBatchUpdateOrders\x1a\x38.injective.exchange.v1beta1.MsgBatchUpdateOrdersResponse\x12\x97\x01\n\x19PrivilegedExecuteContract\x12\x38.injective.exchange.v1beta1.MsgPrivilegedExecuteContract\x1a@.injective.exchange.v1beta1.MsgPrivilegedExecuteContractResponse\x12\x9a\x01\n\x1a\x43reateDerivativeLimitOrder\x12\x39.injective.exchange.v1beta1.MsgCreateDerivativeLimitOrder\x1a\x41.injective.exchange.v1beta1.MsgCreateDerivativeLimitOrderResponse\x12\xac\x01\n BatchCreateDerivativeLimitOrders\x12?.injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrders\x1aG.injective.exchange.v1beta1.MsgBatchCreateDerivativeLimitOrdersResponse\x12\x9d\x01\n\x1b\x43reateDerivativeMarketOrder\x12:.injective.exchange.v1beta1.MsgCreateDerivativeMarketOrder\x1a\x42.injective.exchange.v1beta1.MsgCreateDerivativeMarketOrderResponse\x12\x8b\x01\n\x15\x43\x61ncelDerivativeOrder\x12\x34.injective.exchange.v1beta1.MsgCancelDerivativeOrder\x1a<.injective.exchange.v1beta1.MsgCancelDerivativeOrderResponse\x12\x9d\x01\n\x1b\x42\x61tchCancelDerivativeOrders\x12:.injective.exchange.v1beta1.MsgBatchCancelDerivativeOrders\x1a\x42.injective.exchange.v1beta1.MsgBatchCancelDerivativeOrdersResponse\x12\xac\x01\n InstantBinaryOptionsMarketLaunch\x12?.injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunch\x1aG.injective.exchange.v1beta1.MsgInstantBinaryOptionsMarketLaunchResponse\x12\xa3\x01\n\x1d\x43reateBinaryOptionsLimitOrder\x12<.injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrder\x1a\x44.injective.exchange.v1beta1.MsgCreateBinaryOptionsLimitOrderResponse\x12\xa6\x01\n\x1e\x43reateBinaryOptionsMarketOrder\x12=.injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrder\x1a\x45.injective.exchange.v1beta1.MsgCreateBinaryOptionsMarketOrderResponse\x12\x94\x01\n\x18\x43\x61ncelBinaryOptionsOrder\x12\x37.injective.exchange.v1beta1.MsgCancelBinaryOptionsOrder\x1a?.injective.exchange.v1beta1.MsgCancelBinaryOptionsOrderResponse\x12\xa6\x01\n\x1e\x42\x61tchCancelBinaryOptionsOrders\x12=.injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrders\x1a\x45.injective.exchange.v1beta1.MsgBatchCancelBinaryOptionsOrdersResponse\x12\x82\x01\n\x12SubaccountTransfer\x12\x31.injective.exchange.v1beta1.MsgSubaccountTransfer\x1a\x39.injective.exchange.v1beta1.MsgSubaccountTransferResponse\x12|\n\x10\x45xternalTransfer\x12/.injective.exchange.v1beta1.MsgExternalTransfer\x1a\x37.injective.exchange.v1beta1.MsgExternalTransferResponse\x12\x7f\n\x11LiquidatePosition\x12\x30.injective.exchange.v1beta1.MsgLiquidatePosition\x1a\x38.injective.exchange.v1beta1.MsgLiquidatePositionResponse\x12\x8e\x01\n\x16IncreasePositionMargin\x12\x35.injective.exchange.v1beta1.MsgIncreasePositionMargin\x1a=.injective.exchange.v1beta1.MsgIncreasePositionMarginResponse\x12s\n\rRewardsOptOut\x12,.injective.exchange.v1beta1.MsgRewardsOptOut\x1a\x34.injective.exchange.v1beta1.MsgRewardsOptOutResponse\x12\xa6\x01\n\x1e\x41\x64minUpdateBinaryOptionsMarket\x12=.injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarket\x1a\x45.injective.exchange.v1beta1.MsgAdminUpdateBinaryOptionsMarketResponse\x12\x82\x01\n\x12ReclaimLockedFunds\x12\x31.injective.exchange.v1beta1.MsgReclaimLockedFunds\x1a\x39.injective.exchange.v1beta1.MsgReclaimLockedFundsResponse\x12p\n\x0cUpdateParams\x12+.injective.exchange.v1beta1.MsgUpdateParams\x1a\x33.injective.exchange.v1beta1.MsgUpdateParamsResponseBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSGDEPOSIT.fields_by_name['amount']._options = None
  _MSGDEPOSIT.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGDEPOSIT._options = None
  _MSGDEPOSIT._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGWITHDRAW.fields_by_name['amount']._options = None
  _MSGWITHDRAW.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGWITHDRAW._options = None
  _MSGWITHDRAW._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGCREATESPOTLIMITORDER.fields_by_name['order']._options = None
  _MSGCREATESPOTLIMITORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATESPOTLIMITORDER._options = None
  _MSGCREATESPOTLIMITORDER._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGCREATESPOTLIMITORDERRESPONSE._options = None
  _MSGCREATESPOTLIMITORDERRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGBATCHCREATESPOTLIMITORDERS.fields_by_name['orders']._options = None
  _MSGBATCHCREATESPOTLIMITORDERS.fields_by_name['orders']._serialized_options = b'\310\336\037\000'
  _MSGBATCHCREATESPOTLIMITORDERS._options = None
  _MSGBATCHCREATESPOTLIMITORDERS._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGBATCHCREATESPOTLIMITORDERSRESPONSE._options = None
  _MSGBATCHCREATESPOTLIMITORDERSRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGINSTANTSPOTMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
  _MSGINSTANTSPOTMARKETLAUNCH.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTSPOTMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
  _MSGINSTANTSPOTMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTSPOTMARKETLAUNCH._options = None
  _MSGINSTANTSPOTMARKETLAUNCH._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['maker_fee_rate']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['taker_fee_rate']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['initial_margin_ratio']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['initial_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['maintenance_margin_ratio']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTPERPETUALMARKETLAUNCH._options = None
  _MSGINSTANTPERPETUALMARKETLAUNCH._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['maker_fee_rate']._options = None
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['taker_fee_rate']._options = None
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH._options = None
  _MSGINSTANTBINARYOPTIONSMARKETLAUNCH._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['maker_fee_rate']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['taker_fee_rate']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['initial_margin_ratio']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['initial_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['maintenance_margin_ratio']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['min_price_tick_size']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH._options = None
  _MSGINSTANTEXPIRYFUTURESMARKETLAUNCH._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGCREATESPOTMARKETORDER.fields_by_name['order']._options = None
  _MSGCREATESPOTMARKETORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATESPOTMARKETORDER._options = None
  _MSGCREATESPOTMARKETORDER._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGCREATESPOTMARKETORDERRESPONSE.fields_by_name['results']._options = None
  _MSGCREATESPOTMARKETORDERRESPONSE.fields_by_name['results']._serialized_options = b'\310\336\037\001'
  _MSGCREATESPOTMARKETORDERRESPONSE._options = None
  _MSGCREATESPOTMARKETORDERRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _SPOTMARKETORDERRESULTS.fields_by_name['quantity']._options = None
  _SPOTMARKETORDERRESULTS.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETORDERRESULTS.fields_by_name['price']._options = None
  _SPOTMARKETORDERRESULTS.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETORDERRESULTS.fields_by_name['fee']._options = None
  _SPOTMARKETORDERRESULTS.fields_by_name['fee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETORDERRESULTS._options = None
  _SPOTMARKETORDERRESULTS._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGCREATEDERIVATIVELIMITORDER.fields_by_name['order']._options = None
  _MSGCREATEDERIVATIVELIMITORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATEDERIVATIVELIMITORDER._options = None
  _MSGCREATEDERIVATIVELIMITORDER._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGCREATEDERIVATIVELIMITORDERRESPONSE._options = None
  _MSGCREATEDERIVATIVELIMITORDERRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGCREATEBINARYOPTIONSLIMITORDER.fields_by_name['order']._options = None
  _MSGCREATEBINARYOPTIONSLIMITORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATEBINARYOPTIONSLIMITORDER._options = None
  _MSGCREATEBINARYOPTIONSLIMITORDER._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE._options = None
  _MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGBATCHCREATEDERIVATIVELIMITORDERS.fields_by_name['orders']._options = None
  _MSGBATCHCREATEDERIVATIVELIMITORDERS.fields_by_name['orders']._serialized_options = b'\310\336\037\000'
  _MSGBATCHCREATEDERIVATIVELIMITORDERS._options = None
  _MSGBATCHCREATEDERIVATIVELIMITORDERS._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE._options = None
  _MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGCANCELSPOTORDER._options = None
  _MSGCANCELSPOTORDER._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGBATCHCANCELSPOTORDERS.fields_by_name['data']._options = None
  _MSGBATCHCANCELSPOTORDERS.fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _MSGBATCHCANCELSPOTORDERS._options = None
  _MSGBATCHCANCELSPOTORDERS._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGBATCHCANCELSPOTORDERSRESPONSE._options = None
  _MSGBATCHCANCELSPOTORDERSRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGBATCHCANCELBINARYOPTIONSORDERS.fields_by_name['data']._options = None
  _MSGBATCHCANCELBINARYOPTIONSORDERS.fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _MSGBATCHCANCELBINARYOPTIONSORDERS._options = None
  _MSGBATCHCANCELBINARYOPTIONSORDERS._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE._options = None
  _MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_cancel']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_cancel']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_cancel']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_cancel']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_create']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['spot_orders_to_create']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_create']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['derivative_orders_to_create']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_cancel']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_cancel']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_create']._options = None
  _MSGBATCHUPDATEORDERS.fields_by_name['binary_options_orders_to_create']._serialized_options = b'\310\336\037\001'
  _MSGBATCHUPDATEORDERS._options = None
  _MSGBATCHUPDATEORDERS._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGBATCHUPDATEORDERSRESPONSE._options = None
  _MSGBATCHUPDATEORDERSRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGCREATEDERIVATIVEMARKETORDER.fields_by_name['order']._options = None
  _MSGCREATEDERIVATIVEMARKETORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATEDERIVATIVEMARKETORDER._options = None
  _MSGCREATEDERIVATIVEMARKETORDER._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGCREATEDERIVATIVEMARKETORDERRESPONSE.fields_by_name['results']._options = None
  _MSGCREATEDERIVATIVEMARKETORDERRESPONSE.fields_by_name['results']._serialized_options = b'\310\336\037\001'
  _MSGCREATEDERIVATIVEMARKETORDERRESPONSE._options = None
  _MSGCREATEDERIVATIVEMARKETORDERRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['quantity']._options = None
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['price']._options = None
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['fee']._options = None
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['fee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['position_delta']._options = None
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['position_delta']._serialized_options = b'\310\336\037\000'
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['payout']._options = None
  _DERIVATIVEMARKETORDERRESULTS.fields_by_name['payout']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETORDERRESULTS._options = None
  _DERIVATIVEMARKETORDERRESULTS._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGCREATEBINARYOPTIONSMARKETORDER.fields_by_name['order']._options = None
  _MSGCREATEBINARYOPTIONSMARKETORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _MSGCREATEBINARYOPTIONSMARKETORDER._options = None
  _MSGCREATEBINARYOPTIONSMARKETORDER._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE.fields_by_name['results']._options = None
  _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE.fields_by_name['results']._serialized_options = b'\310\336\037\001'
  _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE._options = None
  _MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGCANCELDERIVATIVEORDER._options = None
  _MSGCANCELDERIVATIVEORDER._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGCANCELBINARYOPTIONSORDER._options = None
  _MSGCANCELBINARYOPTIONSORDER._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGBATCHCANCELDERIVATIVEORDERS.fields_by_name['data']._options = None
  _MSGBATCHCANCELDERIVATIVEORDERS.fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _MSGBATCHCANCELDERIVATIVEORDERS._options = None
  _MSGBATCHCANCELDERIVATIVEORDERS._serialized_options = b'\210\240\037\000\202\347\260*\006sender'
  _MSGBATCHCANCELDERIVATIVEORDERSRESPONSE._options = None
  _MSGBATCHCANCELDERIVATIVEORDERSRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGSUBACCOUNTTRANSFER.fields_by_name['amount']._options = None
  _MSGSUBACCOUNTTRANSFER.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGSUBACCOUNTTRANSFER._options = None
  _MSGSUBACCOUNTTRANSFER._serialized_options = b'\202\347\260*\006sender'
  _MSGEXTERNALTRANSFER.fields_by_name['amount']._options = None
  _MSGEXTERNALTRANSFER.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGEXTERNALTRANSFER._options = None
  _MSGEXTERNALTRANSFER._serialized_options = b'\202\347\260*\006sender'
  _MSGLIQUIDATEPOSITION.fields_by_name['order']._options = None
  _MSGLIQUIDATEPOSITION.fields_by_name['order']._serialized_options = b'\310\336\037\001'
  _MSGLIQUIDATEPOSITION._options = None
  _MSGLIQUIDATEPOSITION._serialized_options = b'\202\347\260*\006sender'
  _MSGINCREASEPOSITIONMARGIN.fields_by_name['amount']._options = None
  _MSGINCREASEPOSITIONMARGIN.fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGINCREASEPOSITIONMARGIN._options = None
  _MSGINCREASEPOSITIONMARGIN._serialized_options = b'\202\347\260*\006sender'
  _MSGPRIVILEGEDEXECUTECONTRACT._options = None
  _MSGPRIVILEGEDEXECUTECONTRACT._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGPRIVILEGEDEXECUTECONTRACTRESPONSE.fields_by_name['funds_diff']._options = None
  _MSGPRIVILEGEDEXECUTECONTRACTRESPONSE.fields_by_name['funds_diff']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGPRIVILEGEDEXECUTECONTRACTRESPONSE._options = None
  _MSGPRIVILEGEDEXECUTECONTRACTRESPONSE._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGRECLAIMLOCKEDFUNDS._options = None
  _MSGRECLAIMLOCKEDFUNDS._serialized_options = b'\202\347\260*\006sender'
  _MSGSIGNDATA.fields_by_name['Signer']._options = None
  _MSGSIGNDATA.fields_by_name['Signer']._serialized_options = b'\352\336\037\006signer\372\336\037-github.com/cosmos/cosmos-sdk/types.AccAddress'
  _MSGSIGNDATA.fields_by_name['Data']._options = None
  _MSGSIGNDATA.fields_by_name['Data']._serialized_options = b'\352\336\037\004data'
  _MSGSIGNDOC.fields_by_name['sign_type']._options = None
  _MSGSIGNDOC.fields_by_name['sign_type']._serialized_options = b'\352\336\037\004type'
  _MSGSIGNDOC.fields_by_name['value']._options = None
  _MSGSIGNDOC.fields_by_name['value']._serialized_options = b'\310\336\037\000'
  _MSGADMINUPDATEBINARYOPTIONSMARKET.fields_by_name['settlement_price']._options = None
  _MSGADMINUPDATEBINARYOPTIONSMARKET.fields_by_name['settlement_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGADMINUPDATEBINARYOPTIONSMARKET._options = None
  _MSGADMINUPDATEBINARYOPTIONSMARKET._serialized_options = b'\202\347\260*\006sender'
  _globals['_MSGUPDATEPARAMS']._serialized_start=304
  _globals['_MSGUPDATEPARAMS']._serialized_end=440
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=442
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=467
  _globals['_MSGDEPOSIT']._serialized_start=469
  _globals['_MSGDEPOSIT']._serialized_end=590
  _globals['_MSGDEPOSITRESPONSE']._serialized_start=592
  _globals['_MSGDEPOSITRESPONSE']._serialized_end=612
  _globals['_MSGWITHDRAW']._serialized_start=614
  _globals['_MSGWITHDRAW']._serialized_end=736
  _globals['_MSGWITHDRAWRESPONSE']._serialized_start=738
  _globals['_MSGWITHDRAWRESPONSE']._serialized_end=759
  _globals['_MSGCREATESPOTLIMITORDER']._serialized_start=761
  _globals['_MSGCREATESPOTLIMITORDER']._serialized_end=883
  _globals['_MSGCREATESPOTLIMITORDERRESPONSE']._serialized_start=885
  _globals['_MSGCREATESPOTLIMITORDERRESPONSE']._serialized_end=948
  _globals['_MSGBATCHCREATESPOTLIMITORDERS']._serialized_start=951
  _globals['_MSGBATCHCREATESPOTLIMITORDERS']._serialized_end=1080
  _globals['_MSGBATCHCREATESPOTLIMITORDERSRESPONSE']._serialized_start=1082
  _globals['_MSGBATCHCREATESPOTLIMITORDERSRESPONSE']._serialized_end=1153
  _globals['_MSGINSTANTSPOTMARKETLAUNCH']._serialized_start=1156
  _globals['_MSGINSTANTSPOTMARKETLAUNCH']._serialized_end=1435
  _globals['_MSGINSTANTSPOTMARKETLAUNCHRESPONSE']._serialized_start=1437
  _globals['_MSGINSTANTSPOTMARKETLAUNCHRESPONSE']._serialized_end=1473
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH']._serialized_start=1476
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCH']._serialized_end=2175
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCHRESPONSE']._serialized_start=2177
  _globals['_MSGINSTANTPERPETUALMARKETLAUNCHRESPONSE']._serialized_end=2218
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH']._serialized_start=2221
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCH']._serialized_end=2844
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCHRESPONSE']._serialized_start=2846
  _globals['_MSGINSTANTBINARYOPTIONSMARKETLAUNCHRESPONSE']._serialized_end=2891
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH']._serialized_start=2894
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCH']._serialized_end=3613
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCHRESPONSE']._serialized_start=3615
  _globals['_MSGINSTANTEXPIRYFUTURESMARKETLAUNCHRESPONSE']._serialized_end=3660
  _globals['_MSGCREATESPOTMARKETORDER']._serialized_start=3662
  _globals['_MSGCREATESPOTMARKETORDER']._serialized_end=3785
  _globals['_MSGCREATESPOTMARKETORDERRESPONSE']._serialized_start=3788
  _globals['_MSGCREATESPOTMARKETORDERRESPONSE']._serialized_end=3927
  _globals['_SPOTMARKETORDERRESULTS']._serialized_start=3930
  _globals['_SPOTMARKETORDERRESULTS']._serialized_end=4154
  _globals['_MSGCREATEDERIVATIVELIMITORDER']._serialized_start=4157
  _globals['_MSGCREATEDERIVATIVELIMITORDER']._serialized_end=4287
  _globals['_MSGCREATEDERIVATIVELIMITORDERRESPONSE']._serialized_start=4289
  _globals['_MSGCREATEDERIVATIVELIMITORDERRESPONSE']._serialized_end=4358
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDER']._serialized_start=4361
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDER']._serialized_end=4494
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE']._serialized_start=4496
  _globals['_MSGCREATEBINARYOPTIONSLIMITORDERRESPONSE']._serialized_end=4568
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERS']._serialized_start=4571
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERS']._serialized_end=4708
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE']._serialized_start=4710
  _globals['_MSGBATCHCREATEDERIVATIVELIMITORDERSRESPONSE']._serialized_end=4787
  _globals['_MSGCANCELSPOTORDER']._serialized_start=4790
  _globals['_MSGCANCELSPOTORDER']._serialized_end=4918
  _globals['_MSGCANCELSPOTORDERRESPONSE']._serialized_start=4920
  _globals['_MSGCANCELSPOTORDERRESPONSE']._serialized_end=4948
  _globals['_MSGBATCHCANCELSPOTORDERS']._serialized_start=4950
  _globals['_MSGBATCHCANCELSPOTORDERS']._serialized_end=5068
  _globals['_MSGBATCHCANCELSPOTORDERSRESPONSE']._serialized_start=5070
  _globals['_MSGBATCHCANCELSPOTORDERSRESPONSE']._serialized_end=5131
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERS']._serialized_start=5133
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERS']._serialized_end=5260
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE']._serialized_start=5262
  _globals['_MSGBATCHCANCELBINARYOPTIONSORDERSRESPONSE']._serialized_end=5332
  _globals['_MSGBATCHUPDATEORDERS']._serialized_start=5335
  _globals['_MSGBATCHUPDATEORDERS']._serialized_end=6046
  _globals['_MSGBATCHUPDATEORDERSRESPONSE']._serialized_start=6049
  _globals['_MSGBATCHUPDATEORDERSRESPONSE']._serialized_end=6289
  _globals['_MSGCREATEDERIVATIVEMARKETORDER']._serialized_start=6292
  _globals['_MSGCREATEDERIVATIVEMARKETORDER']._serialized_end=6423
  _globals['_MSGCREATEDERIVATIVEMARKETORDERRESPONSE']._serialized_start=6426
  _globals['_MSGCREATEDERIVATIVEMARKETORDERRESPONSE']._serialized_end=6577
  _globals['_DERIVATIVEMARKETORDERRESULTS']._serialized_start=6580
  _globals['_DERIVATIVEMARKETORDERRESULTS']._serialized_end=6947
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDER']._serialized_start=6950
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDER']._serialized_end=7084
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE']._serialized_start=7087
  _globals['_MSGCREATEBINARYOPTIONSMARKETORDERRESPONSE']._serialized_end=7241
  _globals['_MSGCANCELDERIVATIVEORDER']._serialized_start=7244
  _globals['_MSGCANCELDERIVATIVEORDER']._serialized_end=7398
  _globals['_MSGCANCELDERIVATIVEORDERRESPONSE']._serialized_start=7400
  _globals['_MSGCANCELDERIVATIVEORDERRESPONSE']._serialized_end=7434
  _globals['_MSGCANCELBINARYOPTIONSORDER']._serialized_start=7437
  _globals['_MSGCANCELBINARYOPTIONSORDER']._serialized_end=7594
  _globals['_MSGCANCELBINARYOPTIONSORDERRESPONSE']._serialized_start=7596
  _globals['_MSGCANCELBINARYOPTIONSORDERRESPONSE']._serialized_end=7633
  _globals['_ORDERDATA']._serialized_start=7635
  _globals['_ORDERDATA']._serialized_end=7741
  _globals['_MSGBATCHCANCELDERIVATIVEORDERS']._serialized_start=7743
  _globals['_MSGBATCHCANCELDERIVATIVEORDERS']._serialized_end=7867
  _globals['_MSGBATCHCANCELDERIVATIVEORDERSRESPONSE']._serialized_start=7869
  _globals['_MSGBATCHCANCELDERIVATIVEORDERSRESPONSE']._serialized_end=7936
  _globals['_MSGSUBACCOUNTTRANSFER']._serialized_start=7939
  _globals['_MSGSUBACCOUNTTRANSFER']._serialized_end=8105
  _globals['_MSGSUBACCOUNTTRANSFERRESPONSE']._serialized_start=8107
  _globals['_MSGSUBACCOUNTTRANSFERRESPONSE']._serialized_end=8138
  _globals['_MSGEXTERNALTRANSFER']._serialized_start=8141
  _globals['_MSGEXTERNALTRANSFER']._serialized_end=8305
  _globals['_MSGEXTERNALTRANSFERRESPONSE']._serialized_start=8307
  _globals['_MSGEXTERNALTRANSFERRESPONSE']._serialized_end=8336
  _globals['_MSGLIQUIDATEPOSITION']._serialized_start=8339
  _globals['_MSGLIQUIDATEPOSITION']._serialized_end=8498
  _globals['_MSGLIQUIDATEPOSITIONRESPONSE']._serialized_start=8500
  _globals['_MSGLIQUIDATEPOSITIONRESPONSE']._serialized_end=8530
  _globals['_MSGINCREASEPOSITIONMARGIN']._serialized_start=8533
  _globals['_MSGINCREASEPOSITIONMARGIN']._serialized_end=8737
  _globals['_MSGINCREASEPOSITIONMARGINRESPONSE']._serialized_start=8739
  _globals['_MSGINCREASEPOSITIONMARGINRESPONSE']._serialized_end=8774
  _globals['_MSGPRIVILEGEDEXECUTECONTRACT']._serialized_start=8776
  _globals['_MSGPRIVILEGEDEXECUTECONTRACT']._serialized_end=8898
  _globals['_MSGPRIVILEGEDEXECUTECONTRACTRESPONSE']._serialized_start=8901
  _globals['_MSGPRIVILEGEDEXECUTECONTRACTRESPONSE']._serialized_end=9057
  _globals['_MSGREWARDSOPTOUT']._serialized_start=9059
  _globals['_MSGREWARDSOPTOUT']._serialized_end=9093
  _globals['_MSGREWARDSOPTOUTRESPONSE']._serialized_start=9095
  _globals['_MSGREWARDSOPTOUTRESPONSE']._serialized_end=9121
  _globals['_MSGRECLAIMLOCKEDFUNDS']._serialized_start=9123
  _globals['_MSGRECLAIMLOCKEDFUNDS']._serialized_end=9223
  _globals['_MSGRECLAIMLOCKEDFUNDSRESPONSE']._serialized_start=9225
  _globals['_MSGRECLAIMLOCKEDFUNDSRESPONSE']._serialized_end=9256
  _globals['_MSGSIGNDATA']._serialized_start=9258
  _globals['_MSGSIGNDATA']._serialized_end=9372
  _globals['_MSGSIGNDOC']._serialized_start=9374
  _globals['_MSGSIGNDOC']._serialized_end=9477
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKET']._serialized_start=9480
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKET']._serialized_end=9755
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKETRESPONSE']._serialized_start=9757
  _globals['_MSGADMINUPDATEBINARYOPTIONSMARKETRESPONSE']._serialized_end=9800
  _globals['_MSG']._serialized_start=9803
  _globals['_MSG']._serialized_end=14171
# @@protoc_insertion_point(module_scope)
