# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from injective.wasmx.v1 import proposal_pb2 as injective_dot_wasmx_dot_v1_dot_proposal__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1finjective/wasmx/v1/events.proto\x12\x12injective.wasmx.v1\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a!injective/wasmx/v1/proposal.proto\x1a\x14gogoproto/gogo.proto\"r\n\x16\x45ventContractExecution\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x10\n\x08response\x18\x02 \x01(\x0c\x12\x13\n\x0bother_error\x18\x03 \x01(\t\x12\x17\n\x0f\x65xecution_error\x18\x04 \x01(\t\"\xf9\x01\n\x17\x45ventContractRegistered\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x11\n\tgas_price\x18\x03 \x01(\x04\x12\x1b\n\x13should_pin_contract\x18\x04 \x01(\x08\x12\x1c\n\x14is_migration_allowed\x18\x05 \x01(\x08\x12\x0f\n\x07\x63ode_id\x18\x06 \x01(\x04\x12\x15\n\radmin_address\x18\x07 \x01(\t\x12\x17\n\x0fgranter_address\x18\x08 \x01(\t\x12\x35\n\x0c\x66unding_mode\x18\t \x01(\x0e\x32\x1f.injective.wasmx.v1.FundingMode\"5\n\x19\x45ventContractDeregistered\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types'
  _globals['_EVENTCONTRACTEXECUTION']._serialized_start=144
  _globals['_EVENTCONTRACTEXECUTION']._serialized_end=258
  _globals['_EVENTCONTRACTREGISTERED']._serialized_start=261
  _globals['_EVENTCONTRACTREGISTERED']._serialized_end=510
  _globals['_EVENTCONTRACTDEREGISTERED']._serialized_start=512
  _globals['_EVENTCONTRACTDEREGISTERED']._serialized_end=565
# @@protoc_insertion_point(module_scope)
