# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_trading_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$exchange/injective_trading_rpc.proto\x12\x15injective_trading_rpc\"\xb3\x01\n\x1cListTradingStrategiesRequest\x12\r\n\x05state\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x04 \x01(\t\x12\x12\n\nstart_time\x18\x05 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x06 \x01(\x12\x12\r\n\x05limit\x18\x07 \x01(\x11\x12\x0c\n\x04skip\x18\x08 \x01(\x04\"\x8a\x01\n\x1dListTradingStrategiesResponse\x12:\n\nstrategies\x18\x01 \x03(\x0b\x32&.injective_trading_rpc.TradingStrategy\x12-\n\x06paging\x18\x02 \x01(\x0b\x32\x1d.injective_trading_rpc.Paging\"\xea\x04\n\x0fTradingStrategy\x12\r\n\x05state\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x04 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x05 \x01(\t\x12\x17\n\x0f\x65xecution_price\x18\x06 \x01(\t\x12\x15\n\rbase_quantity\x18\x07 \x01(\t\x12\x16\n\x0equote_quantity\x18\x14 \x01(\t\x12\x13\n\x0blower_bound\x18\x08 \x01(\t\x12\x13\n\x0bupper_bound\x18\t \x01(\t\x12\x11\n\tstop_loss\x18\n \x01(\t\x12\x13\n\x0btake_profit\x18\x0b \x01(\t\x12\x10\n\x08swap_fee\x18\x0c \x01(\t\x12\x14\n\x0c\x62\x61se_deposit\x18\x11 \x01(\t\x12\x15\n\rquote_deposit\x18\x12 \x01(\t\x12\x18\n\x10market_mid_price\x18\x13 \x01(\t\x12#\n\x1bsubscription_quote_quantity\x18\x15 \x01(\t\x12\"\n\x1asubscription_base_quantity\x18\x16 \x01(\t\x12\x1d\n\x15number_of_grid_levels\x18\x17 \x01(\t\x12#\n\x1bshould_exit_with_quote_only\x18\x18 \x01(\x08\x12\x13\n\x0bstop_reason\x18\x19 \x01(\t\x12\x16\n\x0e\x63reated_height\x18\r \x01(\x12\x12\x16\n\x0eremoved_height\x18\x0e \x01(\x12\x12\x12\n\ncreated_at\x18\x0f \x01(\x12\x12\x12\n\nupdated_at\x18\x10 \x01(\x12\"\\\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\x12\x1b\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12\x12\x0c\n\x04next\x18\x05 \x03(\t2\x9a\x01\n\x13InjectiveTradingRPC\x12\x82\x01\n\x15ListTradingStrategies\x12\x33.injective_trading_rpc.ListTradingStrategiesRequest\x1a\x34.injective_trading_rpc.ListTradingStrategiesResponseB\x1aZ\x18/injective_trading_rpcpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_trading_rpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\030/injective_trading_rpcpb'
  _globals['_LISTTRADINGSTRATEGIESREQUEST']._serialized_start=64
  _globals['_LISTTRADINGSTRATEGIESREQUEST']._serialized_end=243
  _globals['_LISTTRADINGSTRATEGIESRESPONSE']._serialized_start=246
  _globals['_LISTTRADINGSTRATEGIESRESPONSE']._serialized_end=384
  _globals['_TRADINGSTRATEGY']._serialized_start=387
  _globals['_TRADINGSTRATEGY']._serialized_end=1005
  _globals['_PAGING']._serialized_start=1007
  _globals['_PAGING']._serialized_end=1099
  _globals['_INJECTIVETRADINGRPC']._serialized_start=1102
  _globals['_INJECTIVETRADINGRPC']._serialized_end=1256
# @@protoc_insertion_point(module_scope)
