# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_explorer_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_explorer_rpc.proto\x12\x16injective_explorer_rpc\"\xdf\x01\n\x14GetAccountTxsRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0e\n\x06\x62\x65\x66ore\x18\x02 \x01(\x04\x12\r\n\x05\x61\x66ter\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x0e\n\x06module\x18\x07 \x01(\t\x12\x13\n\x0b\x66rom_number\x18\x08 \x01(\x12\x12\x11\n\tto_number\x18\t \x01(\x12\x12\x12\n\nstart_time\x18\n \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x0b \x01(\x12\x12\x0e\n\x06status\x18\x0c \x01(\t\"{\n\x15GetAccountTxsResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.injective_explorer_rpc.TxDetailData\"\\\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\x12\x1b\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12\x12\x0c\n\x04next\x18\x05 \x03(\t\"\xe7\x03\n\x0cTxDetailData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0c\n\x04info\x18\x08 \x01(\t\x12\x12\n\ngas_wanted\x18\t \x01(\x12\x12\x10\n\x08gas_used\x18\n \x01(\x12\x12/\n\x07gas_fee\x18\x0b \x01(\x0b\x32\x1e.injective_explorer_rpc.GasFee\x12\x11\n\tcodespace\x18\x0c \x01(\t\x12-\n\x06\x65vents\x18\r \x03(\x0b\x32\x1d.injective_explorer_rpc.Event\x12\x0f\n\x07tx_type\x18\x0e \x01(\t\x12\x10\n\x08messages\x18\x0f \x01(\x0c\x12\x35\n\nsignatures\x18\x10 \x03(\x0b\x32!.injective_explorer_rpc.Signature\x12\x0c\n\x04memo\x18\x11 \x01(\t\x12\x11\n\ttx_number\x18\x12 \x01(\x04\x12\x1c\n\x14\x62lock_unix_timestamp\x18\x13 \x01(\x04\x12\x11\n\terror_log\x18\x14 \x01(\t\x12\x0c\n\x04logs\x18\x15 \x01(\x0c\x12\x11\n\tclaim_ids\x18\x16 \x03(\x12\"o\n\x06GasFee\x12\x32\n\x06\x61mount\x18\x01 \x03(\x0b\x32\".injective_explorer_rpc.CosmosCoin\x12\x11\n\tgas_limit\x18\x02 \x01(\x04\x12\r\n\x05payer\x18\x03 \x01(\t\x12\x0f\n\x07granter\x18\x04 \x01(\t\"+\n\nCosmosCoin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\x8b\x01\n\x05\x45vent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x41\n\nattributes\x18\x02 \x03(\x0b\x32-.injective_explorer_rpc.Event.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\tSignature\x12\x0e\n\x06pubkey\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x11\n\tsignature\x18\x04 \x01(\t\"m\n\x15GetContractTxsRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x11\x12\x0c\n\x04skip\x18\x03 \x01(\x04\x12\x13\n\x0b\x66rom_number\x18\x04 \x01(\x12\x12\x11\n\tto_number\x18\x05 \x01(\x12\"|\n\x16GetContractTxsResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.injective_explorer_rpc.TxDetailData\"@\n\x10GetBlocksRequest\x12\x0e\n\x06\x62\x65\x66ore\x18\x01 \x01(\x04\x12\r\n\x05\x61\x66ter\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x11\"t\n\x11GetBlocksResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12/\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32!.injective_explorer_rpc.BlockInfo\"\xd4\x01\n\tBlockInfo\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x10\n\x08proposer\x18\x02 \x01(\t\x12\x0f\n\x07moniker\x18\x03 \x01(\t\x12\x12\n\nblock_hash\x18\x04 \x01(\t\x12\x13\n\x0bparent_hash\x18\x05 \x01(\t\x12\x17\n\x0fnum_pre_commits\x18\x06 \x01(\x12\x12\x0f\n\x07num_txs\x18\x07 \x01(\x12\x12.\n\x03txs\x18\x08 \x03(\x0b\x32!.injective_explorer_rpc.TxDataRPC\x12\x11\n\ttimestamp\x18\t \x01(\t\"\xc0\x01\n\tTxDataRPC\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x11\n\tcodespace\x18\x05 \x01(\t\x12\x10\n\x08messages\x18\x06 \x01(\t\x12\x11\n\ttx_number\x18\x07 \x01(\x04\x12\x11\n\terror_log\x18\x08 \x01(\t\x12\x0c\n\x04\x63ode\x18\t \x01(\r\x12\x11\n\tclaim_ids\x18\n \x03(\x12\"\x1d\n\x0fGetBlockRequest\x12\n\n\x02id\x18\x01 \x01(\t\"d\n\x10GetBlockResponse\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrmsg\x18\x02 \x01(\t\x12\x35\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\'.injective_explorer_rpc.BlockDetailInfo\"\xea\x01\n\x0f\x42lockDetailInfo\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x10\n\x08proposer\x18\x02 \x01(\t\x12\x0f\n\x07moniker\x18\x03 \x01(\t\x12\x12\n\nblock_hash\x18\x04 \x01(\t\x12\x13\n\x0bparent_hash\x18\x05 \x01(\t\x12\x17\n\x0fnum_pre_commits\x18\x06 \x01(\x12\x12\x0f\n\x07num_txs\x18\x07 \x01(\x12\x12\x11\n\ttotal_txs\x18\x08 \x01(\x12\x12+\n\x03txs\x18\t \x03(\x0b\x32\x1e.injective_explorer_rpc.TxData\x12\x11\n\ttimestamp\x18\n \x01(\t\"\xe1\x01\n\x06TxData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x11\n\tcodespace\x18\x05 \x01(\t\x12\x10\n\x08messages\x18\x06 \x01(\x0c\x12\x11\n\ttx_number\x18\x07 \x01(\x04\x12\x11\n\terror_log\x18\x08 \x01(\t\x12\x0c\n\x04\x63ode\x18\t \x01(\r\x12\x14\n\x0ctx_msg_types\x18\n \x01(\x0c\x12\x0c\n\x04logs\x18\x0b \x01(\x0c\x12\x11\n\tclaim_ids\x18\x0c \x03(\x12\"\x16\n\x14GetValidatorsRequest\"c\n\x15GetValidatorsResponse\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrmsg\x18\x02 \x01(\t\x12/\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32!.injective_explorer_rpc.Validator\"\x83\x05\n\tValidator\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07moniker\x18\x02 \x01(\t\x12\x18\n\x10operator_address\x18\x03 \x01(\t\x12\x19\n\x11\x63onsensus_address\x18\x04 \x01(\t\x12\x0e\n\x06jailed\x18\x05 \x01(\x08\x12\x0e\n\x06status\x18\x06 \x01(\x11\x12\x0e\n\x06tokens\x18\x07 \x01(\t\x12\x18\n\x10\x64\x65legator_shares\x18\x08 \x01(\t\x12\x41\n\x0b\x64\x65scription\x18\t \x01(\x0b\x32,.injective_explorer_rpc.ValidatorDescription\x12\x18\n\x10unbonding_height\x18\n \x01(\x12\x12\x16\n\x0eunbonding_time\x18\x0b \x01(\t\x12\x17\n\x0f\x63ommission_rate\x18\x0c \x01(\t\x12\x1b\n\x13\x63ommission_max_rate\x18\r \x01(\t\x12\"\n\x1a\x63ommission_max_change_rate\x18\x0e \x01(\t\x12\x1e\n\x16\x63ommission_update_time\x18\x0f \x01(\t\x12\x10\n\x08proposed\x18\x10 \x01(\x04\x12\x0e\n\x06signed\x18\x11 \x01(\x04\x12\x0e\n\x06missed\x18\x12 \x01(\x04\x12\x11\n\ttimestamp\x18\x13 \x01(\t\x12\x38\n\x07uptimes\x18\x14 \x03(\x0b\x32\'.injective_explorer_rpc.ValidatorUptime\x12>\n\x0fslashing_events\x18\x15 \x03(\x0b\x32%.injective_explorer_rpc.SlashingEvent\x12\x19\n\x11uptime_percentage\x18\x16 \x01(\x01\x12\x11\n\timage_url\x18\x17 \x01(\t\"\x88\x01\n\x14ValidatorDescription\x12\x0f\n\x07moniker\x18\x01 \x01(\t\x12\x10\n\x08identity\x18\x02 \x01(\t\x12\x0f\n\x07website\x18\x03 \x01(\t\x12\x18\n\x10security_contact\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t\x12\x11\n\timage_url\x18\x06 \x01(\t\"7\n\x0fValidatorUptime\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\x04\x12\x0e\n\x06status\x18\x02 \x01(\t\"\x95\x01\n\rSlashingEvent\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\r\n\x05power\x18\x04 \x01(\x04\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0e\n\x06jailed\x18\x06 \x01(\t\x12\x15\n\rmissed_blocks\x18\x07 \x01(\x04\"&\n\x13GetValidatorRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"b\n\x14GetValidatorResponse\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrmsg\x18\x02 \x01(\t\x12/\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32!.injective_explorer_rpc.Validator\",\n\x19GetValidatorUptimeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"n\n\x1aGetValidatorUptimeResponse\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrmsg\x18\x02 \x01(\t\x12\x35\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\'.injective_explorer_rpc.ValidatorUptime\"\xc7\x01\n\rGetTxsRequest\x12\x0e\n\x06\x62\x65\x66ore\x18\x01 \x01(\x04\x12\r\n\x05\x61\x66ter\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x11\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x0e\n\x06module\x18\x06 \x01(\t\x12\x13\n\x0b\x66rom_number\x18\x07 \x01(\x12\x12\x11\n\tto_number\x18\x08 \x01(\x12\x12\x12\n\nstart_time\x18\t \x01(\x12\x12\x10\n\x08\x65nd_time\x18\n \x01(\x12\x12\x0e\n\x06status\x18\x0b \x01(\t\"n\n\x0eGetTxsResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12,\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x1e.injective_explorer_rpc.TxData\"$\n\x14GetTxByTxHashRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\"f\n\x15GetTxByTxHashResponse\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0e\n\x06\x65rrmsg\x18\x02 \x01(\t\x12\x32\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32$.injective_explorer_rpc.TxDetailData\"Z\n\x19GetPeggyDepositTxsRequest\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x11\x12\x0c\n\x04skip\x18\x04 \x01(\x04\"S\n\x1aGetPeggyDepositTxsResponse\x12\x35\n\x05\x66ield\x18\x01 \x03(\x0b\x32&.injective_explorer_rpc.PeggyDepositTx\"\xf8\x01\n\x0ePeggyDepositTx\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\x13\n\x0b\x65vent_nonce\x18\x03 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x04 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x05 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x06 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\t\x12\x12\n\nclaim_type\x18\t \x01(\x11\x12\x11\n\ttx_hashes\x18\n \x03(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\t\x12\x12\n\nupdated_at\x18\x0c \x01(\t\"]\n\x1cGetPeggyWithdrawalTxsRequest\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x11\x12\x0c\n\x04skip\x18\x04 \x01(\x04\"Y\n\x1dGetPeggyWithdrawalTxsResponse\x12\x38\n\x05\x66ield\x18\x01 \x03(\x0b\x32).injective_explorer_rpc.PeggyWithdrawalTx\"\xd3\x02\n\x11PeggyWithdrawalTx\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x04 \x01(\t\x12\x12\n\nbridge_fee\x18\x05 \x01(\t\x12\x16\n\x0eoutgoing_tx_id\x18\x06 \x01(\x04\x12\x15\n\rbatch_timeout\x18\x07 \x01(\x04\x12\x13\n\x0b\x62\x61tch_nonce\x18\x08 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\t \x01(\t\x12\x13\n\x0b\x65vent_nonce\x18\n \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x0b \x01(\x04\x12\r\n\x05state\x18\x0c \x01(\t\x12\x12\n\nclaim_type\x18\r \x01(\x11\x12\x11\n\ttx_hashes\x18\x0e \x03(\t\x12\x12\n\ncreated_at\x18\x0f \x01(\t\x12\x12\n\nupdated_at\x18\x10 \x01(\t\"\xa9\x01\n\x18GetIBCTransferTxsRequest\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\x13\n\x0bsrc_channel\x18\x03 \x01(\t\x12\x10\n\x08src_port\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x65st_channel\x18\x05 \x01(\t\x12\x11\n\tdest_port\x18\x06 \x01(\t\x12\r\n\x05limit\x18\x07 \x01(\x11\x12\x0c\n\x04skip\x18\x08 \x01(\x04\"Q\n\x19GetIBCTransferTxsResponse\x12\x34\n\x05\x66ield\x18\x01 \x03(\x0b\x32%.injective_explorer_rpc.IBCTransferTx\"\xdc\x02\n\rIBCTransferTx\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\x13\n\x0bsource_port\x18\x03 \x01(\t\x12\x16\n\x0esource_channel\x18\x04 \x01(\t\x12\x18\n\x10\x64\x65stination_port\x18\x05 \x01(\t\x12\x1b\n\x13\x64\x65stination_channel\x18\x06 \x01(\t\x12\x0e\n\x06\x61mount\x18\x07 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x08 \x01(\t\x12\x16\n\x0etimeout_height\x18\t \x01(\t\x12\x19\n\x11timeout_timestamp\x18\n \x01(\x04\x12\x17\n\x0fpacket_sequence\x18\x0b \x01(\x04\x12\x10\n\x08\x64\x61ta_hex\x18\x0c \x01(\x0c\x12\r\n\x05state\x18\r \x01(\t\x12\x11\n\ttx_hashes\x18\x0e \x03(\t\x12\x12\n\ncreated_at\x18\x0f \x01(\t\x12\x12\n\nupdated_at\x18\x10 \x01(\t\"L\n\x13GetWasmCodesRequest\x12\r\n\x05limit\x18\x01 \x01(\x11\x12\x13\n\x0b\x66rom_number\x18\x02 \x01(\x12\x12\x11\n\tto_number\x18\x03 \x01(\x12\"v\n\x14GetWasmCodesResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12.\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32 .injective_explorer_rpc.WasmCode\"\xd5\x02\n\x08WasmCode\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x04\x12\x0f\n\x07tx_hash\x18\x02 \x01(\t\x12\x32\n\x08\x63hecksum\x18\x03 \x01(\x0b\x32 .injective_explorer_rpc.Checksum\x12\x12\n\ncreated_at\x18\x04 \x01(\x04\x12\x15\n\rcontract_type\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\x12>\n\npermission\x18\x07 \x01(\x0b\x32*.injective_explorer_rpc.ContractPermission\x12\x13\n\x0b\x63ode_schema\x18\x08 \x01(\t\x12\x11\n\tcode_view\x18\t \x01(\t\x12\x14\n\x0cinstantiates\x18\n \x01(\x04\x12\x0f\n\x07\x63reator\x18\x0b \x01(\t\x12\x13\n\x0b\x63ode_number\x18\x0c \x01(\x12\x12\x13\n\x0bproposal_id\x18\r \x01(\x12\"+\n\x08\x43hecksum\x12\x11\n\talgorithm\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t\":\n\x12\x43ontractPermission\x12\x13\n\x0b\x61\x63\x63\x65ss_type\x18\x01 \x01(\x11\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\")\n\x16GetWasmCodeByIDRequest\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x12\"\xe4\x02\n\x17GetWasmCodeByIDResponse\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x04\x12\x0f\n\x07tx_hash\x18\x02 \x01(\t\x12\x32\n\x08\x63hecksum\x18\x03 \x01(\x0b\x32 .injective_explorer_rpc.Checksum\x12\x12\n\ncreated_at\x18\x04 \x01(\x04\x12\x15\n\rcontract_type\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\x12>\n\npermission\x18\x07 \x01(\x0b\x32*.injective_explorer_rpc.ContractPermission\x12\x13\n\x0b\x63ode_schema\x18\x08 \x01(\t\x12\x11\n\tcode_view\x18\t \x01(\t\x12\x14\n\x0cinstantiates\x18\n \x01(\x04\x12\x0f\n\x07\x63reator\x18\x0b \x01(\t\x12\x13\n\x0b\x63ode_number\x18\x0c \x01(\x12\x12\x13\n\x0bproposal_id\x18\r \x01(\x12\"\x93\x01\n\x17GetWasmContractsRequest\x12\r\n\x05limit\x18\x01 \x01(\x11\x12\x0f\n\x07\x63ode_id\x18\x02 \x01(\x12\x12\x13\n\x0b\x66rom_number\x18\x03 \x01(\x12\x12\x11\n\tto_number\x18\x04 \x01(\x12\x12\x13\n\x0b\x61ssets_only\x18\x05 \x01(\x08\x12\x0c\n\x04skip\x18\x06 \x01(\x12\x12\r\n\x05label\x18\x07 \x01(\t\"~\n\x18GetWasmContractsResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.injective_explorer_rpc.WasmContract\"\xab\x03\n\x0cWasmContract\x12\r\n\x05label\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0f\n\x07tx_hash\x18\x03 \x01(\t\x12\x0f\n\x07\x63reator\x18\x04 \x01(\t\x12\x10\n\x08\x65xecutes\x18\x05 \x01(\x04\x12\x17\n\x0finstantiated_at\x18\x06 \x01(\x04\x12\x14\n\x0cinit_message\x18\x07 \x01(\t\x12\x18\n\x10last_executed_at\x18\x08 \x01(\x04\x12\x33\n\x05\x66unds\x18\t \x03(\x0b\x32$.injective_explorer_rpc.ContractFund\x12\x0f\n\x07\x63ode_id\x18\n \x01(\x04\x12\r\n\x05\x61\x64min\x18\x0b \x01(\t\x12\x1f\n\x17\x63urrent_migrate_message\x18\x0c \x01(\t\x12\x17\n\x0f\x63ontract_number\x18\r \x01(\x12\x12\x0f\n\x07version\x18\x0e \x01(\t\x12\x0c\n\x04type\x18\x0f \x01(\t\x12;\n\rcw20_metadata\x18\x10 \x01(\x0b\x32$.injective_explorer_rpc.Cw20Metadata\x12\x13\n\x0bproposal_id\x18\x11 \x01(\x12\"-\n\x0c\x43ontractFund\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\x8c\x01\n\x0c\x43w20Metadata\x12\x39\n\ntoken_info\x18\x01 \x01(\x0b\x32%.injective_explorer_rpc.Cw20TokenInfo\x12\x41\n\x0emarketing_info\x18\x02 \x01(\x0b\x32).injective_explorer_rpc.Cw20MarketingInfo\"U\n\rCw20TokenInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x03 \x01(\x12\x12\x14\n\x0ctotal_supply\x18\x04 \x01(\t\"Z\n\x11\x43w20MarketingInfo\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04logo\x18\x03 \x01(\t\x12\x11\n\tmarketing\x18\x04 \x01(\x0c\";\n\x1fGetWasmContractByAddressRequest\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\"\xbf\x03\n GetWasmContractByAddressResponse\x12\r\n\x05label\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0f\n\x07tx_hash\x18\x03 \x01(\t\x12\x0f\n\x07\x63reator\x18\x04 \x01(\t\x12\x10\n\x08\x65xecutes\x18\x05 \x01(\x04\x12\x17\n\x0finstantiated_at\x18\x06 \x01(\x04\x12\x14\n\x0cinit_message\x18\x07 \x01(\t\x12\x18\n\x10last_executed_at\x18\x08 \x01(\x04\x12\x33\n\x05\x66unds\x18\t \x03(\x0b\x32$.injective_explorer_rpc.ContractFund\x12\x0f\n\x07\x63ode_id\x18\n \x01(\x04\x12\r\n\x05\x61\x64min\x18\x0b \x01(\t\x12\x1f\n\x17\x63urrent_migrate_message\x18\x0c \x01(\t\x12\x17\n\x0f\x63ontract_number\x18\r \x01(\x12\x12\x0f\n\x07version\x18\x0e \x01(\t\x12\x0c\n\x04type\x18\x0f \x01(\t\x12;\n\rcw20_metadata\x18\x10 \x01(\x0b\x32$.injective_explorer_rpc.Cw20Metadata\x12\x13\n\x0bproposal_id\x18\x11 \x01(\x12\"7\n\x15GetCw20BalanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x11\"P\n\x16GetCw20BalanceResponse\x12\x36\n\x05\x66ield\x18\x01 \x03(\x0b\x32\'.injective_explorer_rpc.WasmCw20Balance\"\x9e\x01\n\x0fWasmCw20Balance\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x03 \x01(\t\x12\x12\n\nupdated_at\x18\x04 \x01(\x12\x12;\n\rcw20_metadata\x18\x05 \x01(\x0b\x32$.injective_explorer_rpc.Cw20Metadata\"&\n\x0fRelayersRequest\x12\x13\n\x0bmarket_i_ds\x18\x01 \x03(\t\"I\n\x10RelayersResponse\x12\x35\n\x05\x66ield\x18\x01 \x03(\x0b\x32&.injective_explorer_rpc.RelayerMarkets\"V\n\x0eRelayerMarkets\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x31\n\x08relayers\x18\x02 \x03(\x0b\x32\x1f.injective_explorer_rpc.Relayer\"$\n\x07Relayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x63ta\x18\x02 \x01(\t\"\xd6\x01\n\x17GetBankTransfersRequest\x12\x0f\n\x07senders\x18\x01 \x03(\t\x12\x12\n\nrecipients\x18\x02 \x03(\t\x12!\n\x19is_community_pool_related\x18\x03 \x01(\x08\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x0c\n\x04skip\x18\x05 \x01(\x04\x12\x12\n\nstart_time\x18\x06 \x01(\x12\x12\x10\n\x08\x65nd_time\x18\x07 \x01(\x12\x12\x0f\n\x07\x61\x64\x64ress\x18\x08 \x03(\t\x12\x10\n\x08per_page\x18\t \x01(\x11\x12\r\n\x05token\x18\n \x01(\t\"~\n\x18GetBankTransfersResponse\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x1e.injective_explorer_rpc.Paging\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.injective_explorer_rpc.BankTransfer\"\x8f\x01\n\x0c\x42\x61nkTransfer\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\trecipient\x18\x02 \x01(\t\x12-\n\x07\x61mounts\x18\x03 \x03(\x0b\x32\x1c.injective_explorer_rpc.Coin\x12\x14\n\x0c\x62lock_number\x18\x04 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x05 \x01(\t\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\x12\n\x10StreamTxsRequest\"\xc8\x01\n\x11StreamTxsResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\x12\x17\n\x0f\x62lock_timestamp\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x11\n\tcodespace\x18\x05 \x01(\t\x12\x10\n\x08messages\x18\x06 \x01(\t\x12\x11\n\ttx_number\x18\x07 \x01(\x04\x12\x11\n\terror_log\x18\x08 \x01(\t\x12\x0c\n\x04\x63ode\x18\t \x01(\r\x12\x11\n\tclaim_ids\x18\n \x03(\x12\"\x15\n\x13StreamBlocksRequest\"\xdf\x01\n\x14StreamBlocksResponse\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x10\n\x08proposer\x18\x02 \x01(\t\x12\x0f\n\x07moniker\x18\x03 \x01(\t\x12\x12\n\nblock_hash\x18\x04 \x01(\t\x12\x13\n\x0bparent_hash\x18\x05 \x01(\t\x12\x17\n\x0fnum_pre_commits\x18\x06 \x01(\x12\x12\x0f\n\x07num_txs\x18\x07 \x01(\x12\x12.\n\x03txs\x18\x08 \x03(\x0b\x32!.injective_explorer_rpc.TxDataRPC\x12\x11\n\ttimestamp\x18\t \x01(\t2\xcf\x12\n\x14InjectiveExplorerRPC\x12l\n\rGetAccountTxs\x12,.injective_explorer_rpc.GetAccountTxsRequest\x1a-.injective_explorer_rpc.GetAccountTxsResponse\x12o\n\x0eGetContractTxs\x12-.injective_explorer_rpc.GetContractTxsRequest\x1a..injective_explorer_rpc.GetContractTxsResponse\x12`\n\tGetBlocks\x12(.injective_explorer_rpc.GetBlocksRequest\x1a).injective_explorer_rpc.GetBlocksResponse\x12]\n\x08GetBlock\x12\'.injective_explorer_rpc.GetBlockRequest\x1a(.injective_explorer_rpc.GetBlockResponse\x12l\n\rGetValidators\x12,.injective_explorer_rpc.GetValidatorsRequest\x1a-.injective_explorer_rpc.GetValidatorsResponse\x12i\n\x0cGetValidator\x12+.injective_explorer_rpc.GetValidatorRequest\x1a,.injective_explorer_rpc.GetValidatorResponse\x12{\n\x12GetValidatorUptime\x12\x31.injective_explorer_rpc.GetValidatorUptimeRequest\x1a\x32.injective_explorer_rpc.GetValidatorUptimeResponse\x12W\n\x06GetTxs\x12%.injective_explorer_rpc.GetTxsRequest\x1a&.injective_explorer_rpc.GetTxsResponse\x12l\n\rGetTxByTxHash\x12,.injective_explorer_rpc.GetTxByTxHashRequest\x1a-.injective_explorer_rpc.GetTxByTxHashResponse\x12{\n\x12GetPeggyDepositTxs\x12\x31.injective_explorer_rpc.GetPeggyDepositTxsRequest\x1a\x32.injective_explorer_rpc.GetPeggyDepositTxsResponse\x12\x84\x01\n\x15GetPeggyWithdrawalTxs\x12\x34.injective_explorer_rpc.GetPeggyWithdrawalTxsRequest\x1a\x35.injective_explorer_rpc.GetPeggyWithdrawalTxsResponse\x12x\n\x11GetIBCTransferTxs\x12\x30.injective_explorer_rpc.GetIBCTransferTxsRequest\x1a\x31.injective_explorer_rpc.GetIBCTransferTxsResponse\x12i\n\x0cGetWasmCodes\x12+.injective_explorer_rpc.GetWasmCodesRequest\x1a,.injective_explorer_rpc.GetWasmCodesResponse\x12r\n\x0fGetWasmCodeByID\x12..injective_explorer_rpc.GetWasmCodeByIDRequest\x1a/.injective_explorer_rpc.GetWasmCodeByIDResponse\x12u\n\x10GetWasmContracts\x12/.injective_explorer_rpc.GetWasmContractsRequest\x1a\x30.injective_explorer_rpc.GetWasmContractsResponse\x12\x8d\x01\n\x18GetWasmContractByAddress\x12\x37.injective_explorer_rpc.GetWasmContractByAddressRequest\x1a\x38.injective_explorer_rpc.GetWasmContractByAddressResponse\x12o\n\x0eGetCw20Balance\x12-.injective_explorer_rpc.GetCw20BalanceRequest\x1a..injective_explorer_rpc.GetCw20BalanceResponse\x12]\n\x08Relayers\x12\'.injective_explorer_rpc.RelayersRequest\x1a(.injective_explorer_rpc.RelayersResponse\x12u\n\x10GetBankTransfers\x12/.injective_explorer_rpc.GetBankTransfersRequest\x1a\x30.injective_explorer_rpc.GetBankTransfersResponse\x12\x62\n\tStreamTxs\x12(.injective_explorer_rpc.StreamTxsRequest\x1a).injective_explorer_rpc.StreamTxsResponse0\x01\x12k\n\x0cStreamBlocks\x12+.injective_explorer_rpc.StreamBlocksRequest\x1a,.injective_explorer_rpc.StreamBlocksResponse0\x01\x42\x1bZ\x19/injective_explorer_rpcpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_explorer_rpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\031/injective_explorer_rpcpb'
  _EVENT_ATTRIBUTESENTRY._options = None
  _EVENT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _globals['_GETACCOUNTTXSREQUEST']._serialized_start=66
  _globals['_GETACCOUNTTXSREQUEST']._serialized_end=289
  _globals['_GETACCOUNTTXSRESPONSE']._serialized_start=291
  _globals['_GETACCOUNTTXSRESPONSE']._serialized_end=414
  _globals['_PAGING']._serialized_start=416
  _globals['_PAGING']._serialized_end=508
  _globals['_TXDETAILDATA']._serialized_start=511
  _globals['_TXDETAILDATA']._serialized_end=998
  _globals['_GASFEE']._serialized_start=1000
  _globals['_GASFEE']._serialized_end=1111
  _globals['_COSMOSCOIN']._serialized_start=1113
  _globals['_COSMOSCOIN']._serialized_end=1156
  _globals['_EVENT']._serialized_start=1159
  _globals['_EVENT']._serialized_end=1298
  _globals['_EVENT_ATTRIBUTESENTRY']._serialized_start=1249
  _globals['_EVENT_ATTRIBUTESENTRY']._serialized_end=1298
  _globals['_SIGNATURE']._serialized_start=1300
  _globals['_SIGNATURE']._serialized_end=1381
  _globals['_GETCONTRACTTXSREQUEST']._serialized_start=1383
  _globals['_GETCONTRACTTXSREQUEST']._serialized_end=1492
  _globals['_GETCONTRACTTXSRESPONSE']._serialized_start=1494
  _globals['_GETCONTRACTTXSRESPONSE']._serialized_end=1618
  _globals['_GETBLOCKSREQUEST']._serialized_start=1620
  _globals['_GETBLOCKSREQUEST']._serialized_end=1684
  _globals['_GETBLOCKSRESPONSE']._serialized_start=1686
  _globals['_GETBLOCKSRESPONSE']._serialized_end=1802
  _globals['_BLOCKINFO']._serialized_start=1805
  _globals['_BLOCKINFO']._serialized_end=2017
  _globals['_TXDATARPC']._serialized_start=2020
  _globals['_TXDATARPC']._serialized_end=2212
  _globals['_GETBLOCKREQUEST']._serialized_start=2214
  _globals['_GETBLOCKREQUEST']._serialized_end=2243
  _globals['_GETBLOCKRESPONSE']._serialized_start=2245
  _globals['_GETBLOCKRESPONSE']._serialized_end=2345
  _globals['_BLOCKDETAILINFO']._serialized_start=2348
  _globals['_BLOCKDETAILINFO']._serialized_end=2582
  _globals['_TXDATA']._serialized_start=2585
  _globals['_TXDATA']._serialized_end=2810
  _globals['_GETVALIDATORSREQUEST']._serialized_start=2812
  _globals['_GETVALIDATORSREQUEST']._serialized_end=2834
  _globals['_GETVALIDATORSRESPONSE']._serialized_start=2836
  _globals['_GETVALIDATORSRESPONSE']._serialized_end=2935
  _globals['_VALIDATOR']._serialized_start=2938
  _globals['_VALIDATOR']._serialized_end=3581
  _globals['_VALIDATORDESCRIPTION']._serialized_start=3584
  _globals['_VALIDATORDESCRIPTION']._serialized_end=3720
  _globals['_VALIDATORUPTIME']._serialized_start=3722
  _globals['_VALIDATORUPTIME']._serialized_end=3777
  _globals['_SLASHINGEVENT']._serialized_start=3780
  _globals['_SLASHINGEVENT']._serialized_end=3929
  _globals['_GETVALIDATORREQUEST']._serialized_start=3931
  _globals['_GETVALIDATORREQUEST']._serialized_end=3969
  _globals['_GETVALIDATORRESPONSE']._serialized_start=3971
  _globals['_GETVALIDATORRESPONSE']._serialized_end=4069
  _globals['_GETVALIDATORUPTIMEREQUEST']._serialized_start=4071
  _globals['_GETVALIDATORUPTIMEREQUEST']._serialized_end=4115
  _globals['_GETVALIDATORUPTIMERESPONSE']._serialized_start=4117
  _globals['_GETVALIDATORUPTIMERESPONSE']._serialized_end=4227
  _globals['_GETTXSREQUEST']._serialized_start=4230
  _globals['_GETTXSREQUEST']._serialized_end=4429
  _globals['_GETTXSRESPONSE']._serialized_start=4431
  _globals['_GETTXSRESPONSE']._serialized_end=4541
  _globals['_GETTXBYTXHASHREQUEST']._serialized_start=4543
  _globals['_GETTXBYTXHASHREQUEST']._serialized_end=4579
  _globals['_GETTXBYTXHASHRESPONSE']._serialized_start=4581
  _globals['_GETTXBYTXHASHRESPONSE']._serialized_end=4683
  _globals['_GETPEGGYDEPOSITTXSREQUEST']._serialized_start=4685
  _globals['_GETPEGGYDEPOSITTXSREQUEST']._serialized_end=4775
  _globals['_GETPEGGYDEPOSITTXSRESPONSE']._serialized_start=4777
  _globals['_GETPEGGYDEPOSITTXSRESPONSE']._serialized_end=4860
  _globals['_PEGGYDEPOSITTX']._serialized_start=4863
  _globals['_PEGGYDEPOSITTX']._serialized_end=5111
  _globals['_GETPEGGYWITHDRAWALTXSREQUEST']._serialized_start=5113
  _globals['_GETPEGGYWITHDRAWALTXSREQUEST']._serialized_end=5206
  _globals['_GETPEGGYWITHDRAWALTXSRESPONSE']._serialized_start=5208
  _globals['_GETPEGGYWITHDRAWALTXSRESPONSE']._serialized_end=5297
  _globals['_PEGGYWITHDRAWALTX']._serialized_start=5300
  _globals['_PEGGYWITHDRAWALTX']._serialized_end=5639
  _globals['_GETIBCTRANSFERTXSREQUEST']._serialized_start=5642
  _globals['_GETIBCTRANSFERTXSREQUEST']._serialized_end=5811
  _globals['_GETIBCTRANSFERTXSRESPONSE']._serialized_start=5813
  _globals['_GETIBCTRANSFERTXSRESPONSE']._serialized_end=5894
  _globals['_IBCTRANSFERTX']._serialized_start=5897
  _globals['_IBCTRANSFERTX']._serialized_end=6245
  _globals['_GETWASMCODESREQUEST']._serialized_start=6247
  _globals['_GETWASMCODESREQUEST']._serialized_end=6323
  _globals['_GETWASMCODESRESPONSE']._serialized_start=6325
  _globals['_GETWASMCODESRESPONSE']._serialized_end=6443
  _globals['_WASMCODE']._serialized_start=6446
  _globals['_WASMCODE']._serialized_end=6787
  _globals['_CHECKSUM']._serialized_start=6789
  _globals['_CHECKSUM']._serialized_end=6832
  _globals['_CONTRACTPERMISSION']._serialized_start=6834
  _globals['_CONTRACTPERMISSION']._serialized_end=6892
  _globals['_GETWASMCODEBYIDREQUEST']._serialized_start=6894
  _globals['_GETWASMCODEBYIDREQUEST']._serialized_end=6935
  _globals['_GETWASMCODEBYIDRESPONSE']._serialized_start=6938
  _globals['_GETWASMCODEBYIDRESPONSE']._serialized_end=7294
  _globals['_GETWASMCONTRACTSREQUEST']._serialized_start=7297
  _globals['_GETWASMCONTRACTSREQUEST']._serialized_end=7444
  _globals['_GETWASMCONTRACTSRESPONSE']._serialized_start=7446
  _globals['_GETWASMCONTRACTSRESPONSE']._serialized_end=7572
  _globals['_WASMCONTRACT']._serialized_start=7575
  _globals['_WASMCONTRACT']._serialized_end=8002
  _globals['_CONTRACTFUND']._serialized_start=8004
  _globals['_CONTRACTFUND']._serialized_end=8049
  _globals['_CW20METADATA']._serialized_start=8052
  _globals['_CW20METADATA']._serialized_end=8192
  _globals['_CW20TOKENINFO']._serialized_start=8194
  _globals['_CW20TOKENINFO']._serialized_end=8279
  _globals['_CW20MARKETINGINFO']._serialized_start=8281
  _globals['_CW20MARKETINGINFO']._serialized_end=8371
  _globals['_GETWASMCONTRACTBYADDRESSREQUEST']._serialized_start=8373
  _globals['_GETWASMCONTRACTBYADDRESSREQUEST']._serialized_end=8432
  _globals['_GETWASMCONTRACTBYADDRESSRESPONSE']._serialized_start=8435
  _globals['_GETWASMCONTRACTBYADDRESSRESPONSE']._serialized_end=8882
  _globals['_GETCW20BALANCEREQUEST']._serialized_start=8884
  _globals['_GETCW20BALANCEREQUEST']._serialized_end=8939
  _globals['_GETCW20BALANCERESPONSE']._serialized_start=8941
  _globals['_GETCW20BALANCERESPONSE']._serialized_end=9021
  _globals['_WASMCW20BALANCE']._serialized_start=9024
  _globals['_WASMCW20BALANCE']._serialized_end=9182
  _globals['_RELAYERSREQUEST']._serialized_start=9184
  _globals['_RELAYERSREQUEST']._serialized_end=9222
  _globals['_RELAYERSRESPONSE']._serialized_start=9224
  _globals['_RELAYERSRESPONSE']._serialized_end=9297
  _globals['_RELAYERMARKETS']._serialized_start=9299
  _globals['_RELAYERMARKETS']._serialized_end=9385
  _globals['_RELAYER']._serialized_start=9387
  _globals['_RELAYER']._serialized_end=9423
  _globals['_GETBANKTRANSFERSREQUEST']._serialized_start=9426
  _globals['_GETBANKTRANSFERSREQUEST']._serialized_end=9640
  _globals['_GETBANKTRANSFERSRESPONSE']._serialized_start=9642
  _globals['_GETBANKTRANSFERSRESPONSE']._serialized_end=9768
  _globals['_BANKTRANSFER']._serialized_start=9771
  _globals['_BANKTRANSFER']._serialized_end=9914
  _globals['_COIN']._serialized_start=9916
  _globals['_COIN']._serialized_end=9953
  _globals['_STREAMTXSREQUEST']._serialized_start=9955
  _globals['_STREAMTXSREQUEST']._serialized_end=9973
  _globals['_STREAMTXSRESPONSE']._serialized_start=9976
  _globals['_STREAMTXSRESPONSE']._serialized_end=10176
  _globals['_STREAMBLOCKSREQUEST']._serialized_start=10178
  _globals['_STREAMBLOCKSREQUEST']._serialized_end=10199
  _globals['_STREAMBLOCKSRESPONSE']._serialized_start=10202
  _globals['_STREAMBLOCKSRESPONSE']._serialized_end=10425
  _globals['_INJECTIVEEXPLORERRPC']._serialized_start=10428
  _globals['_INJECTIVEEXPLORERRPC']._serialized_end=12811
# @@protoc_insertion_point(module_scope)
