# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: testpb/test_schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from cosmos.orm.v1 import orm_pb2 as cosmos_dot_orm_dot_v1_dot_orm__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18testpb/test_schema.proto\x12\x06testpb\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17\x63osmos/orm/v1/orm.proto\"\xc0\x04\n\x0c\x45xampleTable\x12\x0b\n\x03u32\x18\x01 \x01(\r\x12\x0b\n\x03u64\x18\x02 \x01(\x04\x12\x0b\n\x03str\x18\x03 \x01(\t\x12\n\n\x02\x62z\x18\x04 \x01(\x0c\x12&\n\x02ts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x03\x64ur\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0b\n\x03i32\x18\x07 \x01(\x05\x12\x0b\n\x03s32\x18\x08 \x01(\x11\x12\x0c\n\x04sf32\x18\t \x01(\x0f\x12\x0b\n\x03i64\x18\n \x01(\x03\x12\x0b\n\x03s64\x18\x0b \x01(\x12\x12\x0c\n\x04sf64\x18\x0c \x01(\x10\x12\x0b\n\x03\x66\x33\x32\x18\r \x01(\x07\x12\x0b\n\x03\x66\x36\x34\x18\x0e \x01(\x06\x12\t\n\x01\x62\x18\x0f \x01(\x08\x12\x17\n\x01\x65\x18\x10 \x01(\x0e\x32\x0c.testpb.Enum\x12\x10\n\x08repeated\x18\x11 \x03(\r\x12*\n\x03map\x18\x12 \x03(\x0b\x32\x1d.testpb.ExampleTable.MapEntry\x12\x30\n\x03msg\x18\x13 \x01(\x0b\x32#.testpb.ExampleTable.ExampleMessage\x12\x0f\n\x05oneof\x18\x14 \x01(\rH\x00\x1a*\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x1a*\n\x0e\x45xampleMessage\x12\x0b\n\x03\x66oo\x18\x01 \x01(\t\x12\x0b\n\x03\x62\x61r\x18\x02 \x01(\x05:?\xf2\x9e\xd3\x8e\x03\x39\n\r\n\x0bu32,i64,str\x12\r\n\x07u64,str\x10\x01\x18\x01\x12\x0b\n\x07str,u32\x10\x02\x12\n\n\x06\x62z,str\x10\x03\x18\x01\x42\x05\n\x03sum\"X\n\x19\x45xampleAutoIncrementTable\x12\n\n\x02id\x18\x01 \x01(\x04\x12\t\n\x01x\x18\x02 \x01(\t\x12\t\n\x01y\x18\x03 \x01(\x05:\x19\xf2\x9e\xd3\x8e\x03\x13\n\x06\n\x02id\x10\x01\x12\x07\n\x01x\x10\x01\x18\x01\x18\x03\"6\n\x10\x45xampleSingleton\x12\x0b\n\x03\x66oo\x18\x01 \x01(\t\x12\x0b\n\x03\x62\x61r\x18\x02 \x01(\x05:\x08\xfa\x9e\xd3\x8e\x03\x02\x08\x02\"n\n\x10\x45xampleTimestamp\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12&\n\x02ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x18\xf2\x9e\xd3\x8e\x03\x12\n\x06\n\x02id\x10\x01\x12\x06\n\x02ts\x10\x01\x18\x04\"a\n\rSimpleExample\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06unique\x18\x02 \x01(\t\x12\x12\n\nnot_unique\x18\x03 \x01(\t:\x1e\xf2\x9e\xd3\x8e\x03\x18\n\x06\n\x04name\x12\x0c\n\x06unique\x10\x01\x18\x01\x18\x05\"F\n\x17\x45xampleAutoIncFieldName\x12\x0b\n\x03\x66oo\x18\x01 \x01(\x04\x12\x0b\n\x03\x62\x61r\x18\x02 \x01(\x04:\x11\xf2\x9e\xd3\x8e\x03\x0b\n\x07\n\x03\x66oo\x10\x01\x18\x06*d\n\x04\x45num\x12\x14\n\x10\x45NUM_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x45NUM_ONE\x10\x01\x12\x0c\n\x08\x45NUM_TWO\x10\x02\x12\r\n\tENUM_FIVE\x10\x05\x12\x1b\n\x0e\x45NUM_NEG_THREE\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'testpb.test_schema_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXAMPLETABLE_MAPENTRY._options = None
  _EXAMPLETABLE_MAPENTRY._serialized_options = b'8\001'
  _EXAMPLETABLE._options = None
  _EXAMPLETABLE._serialized_options = b'\362\236\323\216\0039\n\r\n\013u32,i64,str\022\r\n\007u64,str\020\001\030\001\022\013\n\007str,u32\020\002\022\n\n\006bz,str\020\003\030\001'
  _EXAMPLEAUTOINCREMENTTABLE._options = None
  _EXAMPLEAUTOINCREMENTTABLE._serialized_options = b'\362\236\323\216\003\023\n\006\n\002id\020\001\022\007\n\001x\020\001\030\001\030\003'
  _EXAMPLESINGLETON._options = None
  _EXAMPLESINGLETON._serialized_options = b'\372\236\323\216\003\002\010\002'
  _EXAMPLETIMESTAMP._options = None
  _EXAMPLETIMESTAMP._serialized_options = b'\362\236\323\216\003\022\n\006\n\002id\020\001\022\006\n\002ts\020\001\030\004'
  _SIMPLEEXAMPLE._options = None
  _SIMPLEEXAMPLE._serialized_options = b'\362\236\323\216\003\030\n\006\n\004name\022\014\n\006unique\020\001\030\001\030\005'
  _EXAMPLEAUTOINCFIELDNAME._options = None
  _EXAMPLEAUTOINCFIELDNAME._serialized_options = b'\362\236\323\216\003\013\n\007\n\003foo\020\001\030\006'
  _globals['_ENUM']._serialized_start=1134
  _globals['_ENUM']._serialized_end=1234
  _globals['_EXAMPLETABLE']._serialized_start=127
  _globals['_EXAMPLETABLE']._serialized_end=703
  _globals['_EXAMPLETABLE_MAPENTRY']._serialized_start=545
  _globals['_EXAMPLETABLE_MAPENTRY']._serialized_end=587
  _globals['_EXAMPLETABLE_EXAMPLEMESSAGE']._serialized_start=589
  _globals['_EXAMPLETABLE_EXAMPLEMESSAGE']._serialized_end=631
  _globals['_EXAMPLEAUTOINCREMENTTABLE']._serialized_start=705
  _globals['_EXAMPLEAUTOINCREMENTTABLE']._serialized_end=793
  _globals['_EXAMPLESINGLETON']._serialized_start=795
  _globals['_EXAMPLESINGLETON']._serialized_end=849
  _globals['_EXAMPLETIMESTAMP']._serialized_start=851
  _globals['_EXAMPLETIMESTAMP']._serialized_end=961
  _globals['_SIMPLEEXAMPLE']._serialized_start=963
  _globals['_SIMPLEEXAMPLE']._serialized_end=1060
  _globals['_EXAMPLEAUTOINCFIELDNAME']._serialized_start=1062
  _globals['_EXAMPLEAUTOINCFIELDNAME']._serialized_end=1132
# @@protoc_insertion_point(module_scope)
