# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_accounts_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_accounts_rpc.proto\x12\x16injective_accounts_rpc\"+\n\x10PortfolioRequest\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\"P\n\x11PortfolioResponse\x12;\n\tportfolio\x18\x01 \x01(\x0b\x32(.injective_accounts_rpc.AccountPortfolio\"\xb8\x01\n\x10\x41\x63\x63ountPortfolio\x12\x17\n\x0fportfolio_value\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\x12\x16\n\x0elocked_balance\x18\x03 \x01(\t\x12\x16\n\x0eunrealized_pnl\x18\x04 \x01(\t\x12@\n\x0bsubaccounts\x18\x05 \x03(\x0b\x32+.injective_accounts_rpc.SubaccountPortfolio\"w\n\x13SubaccountPortfolio\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\x12\x16\n\x0elocked_balance\x18\x03 \x01(\t\x12\x16\n\x0eunrealized_pnl\x18\x04 \x01(\t\"P\n\x12OrderStatesRequest\x12\x19\n\x11spot_order_hashes\x18\x01 \x03(\t\x12\x1f\n\x17\x64\x65rivative_order_hashes\x18\x02 \x03(\t\"\xa5\x01\n\x13OrderStatesResponse\x12\x43\n\x11spot_order_states\x18\x01 \x03(\x0b\x32(.injective_accounts_rpc.OrderStateRecord\x12I\n\x17\x64\x65rivative_order_states\x18\x02 \x03(\x0b\x32(.injective_accounts_rpc.OrderStateRecord\"\xe4\x01\n\x10OrderStateRecord\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x12\n\norder_type\x18\x04 \x01(\t\x12\x12\n\norder_side\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x17\n\x0fquantity_filled\x18\x07 \x01(\t\x12\x1a\n\x12quantity_remaining\x18\x08 \x01(\t\x12\x12\n\ncreated_at\x18\t \x01(\x12\x12\x12\n\nupdated_at\x18\n \x01(\x12\"1\n\x16SubaccountsListRequest\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\".\n\x17SubaccountsListResponse\x12\x13\n\x0bsubaccounts\x18\x01 \x03(\t\"F\n\x1dSubaccountBalancesListRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65noms\x18\x02 \x03(\t\"]\n\x1eSubaccountBalancesListResponse\x12;\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32).injective_accounts_rpc.SubaccountBalance\"\x8e\x01\n\x11SubaccountBalance\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\x12:\n\x07\x64\x65posit\x18\x04 \x01(\x0b\x32).injective_accounts_rpc.SubaccountDeposit\"E\n\x11SubaccountDeposit\x12\x15\n\rtotal_balance\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\"H\n SubaccountBalanceEndpointRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"_\n!SubaccountBalanceEndpointResponse\x12:\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32).injective_accounts_rpc.SubaccountBalance\"G\n\x1eStreamSubaccountBalanceRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65noms\x18\x02 \x03(\t\"p\n\x1fStreamSubaccountBalanceResponse\x12:\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32).injective_accounts_rpc.SubaccountBalance\x12\x11\n\ttimestamp\x18\x02 \x01(\x12\"\x87\x01\n\x18SubaccountHistoryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x16\n\x0etransfer_types\x18\x03 \x03(\t\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x11\x12\x10\n\x08\x65nd_time\x18\x06 \x01(\x12\"\x91\x01\n\x19SubaccountHistoryResponse\x12\x44\n\ttransfers\x18\x01 \x03(\x0b\x32\x31.injective_accounts_rpc.SubaccountBalanceTransfer\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x1e.injective_accounts_rpc.Paging\"\xeb\x01\n\x19SubaccountBalanceTransfer\x12\x15\n\rtransfer_type\x18\x01 \x01(\t\x12\x19\n\x11src_subaccount_id\x18\x02 \x01(\t\x12\x1b\n\x13src_account_address\x18\x03 \x01(\t\x12\x19\n\x11\x64st_subaccount_id\x18\x04 \x01(\t\x12\x1b\n\x13\x64st_account_address\x18\x05 \x01(\t\x12\x32\n\x06\x61mount\x18\x06 \x01(\x0b\x32\".injective_accounts_rpc.CosmosCoin\x12\x13\n\x0b\x65xecuted_at\x18\x07 \x01(\x12\"+\n\nCosmosCoin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\\\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\x12\x1b\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12\x12\x0c\n\x04next\x18\x05 \x03(\t\"b\n\x1dSubaccountOrderSummaryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x17\n\x0forder_direction\x18\x03 \x01(\t\"\\\n\x1eSubaccountOrderSummaryResponse\x12\x19\n\x11spot_orders_total\x18\x01 \x01(\x12\x12\x1f\n\x17\x64\x65rivative_orders_total\x18\x02 \x01(\x12\"8\n\x0eRewardsRequest\x12\r\n\x05\x65poch\x18\x01 \x01(\x12\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\t\"B\n\x0fRewardsResponse\x12/\n\x07rewards\x18\x01 \x03(\x0b\x32\x1e.injective_accounts_rpc.Reward\"h\n\x06Reward\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12-\n\x07rewards\x18\x02 \x03(\x0b\x32\x1c.injective_accounts_rpc.Coin\x12\x16\n\x0e\x64istributed_at\x18\x03 \x01(\x12\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t2\xe0\x08\n\x14InjectiveAccountsRPC\x12`\n\tPortfolio\x12(.injective_accounts_rpc.PortfolioRequest\x1a).injective_accounts_rpc.PortfolioResponse\x12\x66\n\x0bOrderStates\x12*.injective_accounts_rpc.OrderStatesRequest\x1a+.injective_accounts_rpc.OrderStatesResponse\x12r\n\x0fSubaccountsList\x12..injective_accounts_rpc.SubaccountsListRequest\x1a/.injective_accounts_rpc.SubaccountsListResponse\x12\x87\x01\n\x16SubaccountBalancesList\x12\x35.injective_accounts_rpc.SubaccountBalancesListRequest\x1a\x36.injective_accounts_rpc.SubaccountBalancesListResponse\x12\x90\x01\n\x19SubaccountBalanceEndpoint\x12\x38.injective_accounts_rpc.SubaccountBalanceEndpointRequest\x1a\x39.injective_accounts_rpc.SubaccountBalanceEndpointResponse\x12\x8c\x01\n\x17StreamSubaccountBalance\x12\x36.injective_accounts_rpc.StreamSubaccountBalanceRequest\x1a\x37.injective_accounts_rpc.StreamSubaccountBalanceResponse0\x01\x12x\n\x11SubaccountHistory\x12\x30.injective_accounts_rpc.SubaccountHistoryRequest\x1a\x31.injective_accounts_rpc.SubaccountHistoryResponse\x12\x87\x01\n\x16SubaccountOrderSummary\x12\x35.injective_accounts_rpc.SubaccountOrderSummaryRequest\x1a\x36.injective_accounts_rpc.SubaccountOrderSummaryResponse\x12Z\n\x07Rewards\x12&.injective_accounts_rpc.RewardsRequest\x1a\'.injective_accounts_rpc.RewardsResponseB\x1bZ\x19/injective_accounts_rpcpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_accounts_rpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\031/injective_accounts_rpcpb'
  _globals['_PORTFOLIOREQUEST']._serialized_start=65
  _globals['_PORTFOLIOREQUEST']._serialized_end=108
  _globals['_PORTFOLIORESPONSE']._serialized_start=110
  _globals['_PORTFOLIORESPONSE']._serialized_end=190
  _globals['_ACCOUNTPORTFOLIO']._serialized_start=193
  _globals['_ACCOUNTPORTFOLIO']._serialized_end=377
  _globals['_SUBACCOUNTPORTFOLIO']._serialized_start=379
  _globals['_SUBACCOUNTPORTFOLIO']._serialized_end=498
  _globals['_ORDERSTATESREQUEST']._serialized_start=500
  _globals['_ORDERSTATESREQUEST']._serialized_end=580
  _globals['_ORDERSTATESRESPONSE']._serialized_start=583
  _globals['_ORDERSTATESRESPONSE']._serialized_end=748
  _globals['_ORDERSTATERECORD']._serialized_start=751
  _globals['_ORDERSTATERECORD']._serialized_end=979
  _globals['_SUBACCOUNTSLISTREQUEST']._serialized_start=981
  _globals['_SUBACCOUNTSLISTREQUEST']._serialized_end=1030
  _globals['_SUBACCOUNTSLISTRESPONSE']._serialized_start=1032
  _globals['_SUBACCOUNTSLISTRESPONSE']._serialized_end=1078
  _globals['_SUBACCOUNTBALANCESLISTREQUEST']._serialized_start=1080
  _globals['_SUBACCOUNTBALANCESLISTREQUEST']._serialized_end=1150
  _globals['_SUBACCOUNTBALANCESLISTRESPONSE']._serialized_start=1152
  _globals['_SUBACCOUNTBALANCESLISTRESPONSE']._serialized_end=1245
  _globals['_SUBACCOUNTBALANCE']._serialized_start=1248
  _globals['_SUBACCOUNTBALANCE']._serialized_end=1390
  _globals['_SUBACCOUNTDEPOSIT']._serialized_start=1392
  _globals['_SUBACCOUNTDEPOSIT']._serialized_end=1461
  _globals['_SUBACCOUNTBALANCEENDPOINTREQUEST']._serialized_start=1463
  _globals['_SUBACCOUNTBALANCEENDPOINTREQUEST']._serialized_end=1535
  _globals['_SUBACCOUNTBALANCEENDPOINTRESPONSE']._serialized_start=1537
  _globals['_SUBACCOUNTBALANCEENDPOINTRESPONSE']._serialized_end=1632
  _globals['_STREAMSUBACCOUNTBALANCEREQUEST']._serialized_start=1634
  _globals['_STREAMSUBACCOUNTBALANCEREQUEST']._serialized_end=1705
  _globals['_STREAMSUBACCOUNTBALANCERESPONSE']._serialized_start=1707
  _globals['_STREAMSUBACCOUNTBALANCERESPONSE']._serialized_end=1819
  _globals['_SUBACCOUNTHISTORYREQUEST']._serialized_start=1822
  _globals['_SUBACCOUNTHISTORYREQUEST']._serialized_end=1957
  _globals['_SUBACCOUNTHISTORYRESPONSE']._serialized_start=1960
  _globals['_SUBACCOUNTHISTORYRESPONSE']._serialized_end=2105
  _globals['_SUBACCOUNTBALANCETRANSFER']._serialized_start=2108
  _globals['_SUBACCOUNTBALANCETRANSFER']._serialized_end=2343
  _globals['_COSMOSCOIN']._serialized_start=2345
  _globals['_COSMOSCOIN']._serialized_end=2388
  _globals['_PAGING']._serialized_start=2390
  _globals['_PAGING']._serialized_end=2482
  _globals['_SUBACCOUNTORDERSUMMARYREQUEST']._serialized_start=2484
  _globals['_SUBACCOUNTORDERSUMMARYREQUEST']._serialized_end=2582
  _globals['_SUBACCOUNTORDERSUMMARYRESPONSE']._serialized_start=2584
  _globals['_SUBACCOUNTORDERSUMMARYRESPONSE']._serialized_end=2676
  _globals['_REWARDSREQUEST']._serialized_start=2678
  _globals['_REWARDSREQUEST']._serialized_end=2734
  _globals['_REWARDSRESPONSE']._serialized_start=2736
  _globals['_REWARDSRESPONSE']._serialized_end=2802
  _globals['_REWARD']._serialized_start=2804
  _globals['_REWARD']._serialized_end=2908
  _globals['_COIN']._serialized_start=2910
  _globals['_COIN']._serialized_end=2947
  _globals['_INJECTIVEACCOUNTSRPC']._serialized_start=2950
  _globals['_INJECTIVEACCOUNTSRPC']._serialized_end=4070
# @@protoc_insertion_point(module_scope)
