# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/tx_response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/types/v1beta1/tx_response.proto\x12\x17injective.types.v1beta1\"8\n\x18TxResponseGenericMessage\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"U\n\x0eTxResponseData\x12\x43\n\x08messages\x18\x01 \x03(\x0b\x32\x31.injective.types.v1beta1.TxResponseGenericMessageB?Z=github.com/InjectiveLabs/injective-core/injective-chain/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.types.v1beta1.tx_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z=github.com/InjectiveLabs/injective-core/injective-chain/types'
  _globals['_TXRESPONSEGENERICMESSAGE']._serialized_start=70
  _globals['_TXRESPONSEGENERICMESSAGE']._serialized_end=126
  _globals['_TXRESPONSEDATA']._serialized_start=128
  _globals['_TXRESPONSEDATA']._serialized_end=213
# @@protoc_insertion_point(module_scope)
