# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from injective.auction.v1beta1 import auction_pb2 as injective_dot_auction_dot_v1beta1_dot_auction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"injective/auction/v1beta1/tx.proto\x12\x19injective.auction.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\'injective/auction/v1beta1/auction.proto\"q\n\x06MsgBid\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x33\n\nbid_amount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\r\n\x05round\x18\x03 \x01(\x04:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x10\n\x0eMsgBidResponse\"\x87\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32!.injective.auction.v1beta1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xca\x01\n\x03Msg\x12S\n\x03\x42id\x12!.injective.auction.v1beta1.MsgBid\x1a).injective.auction.v1beta1.MsgBidResponse\x12n\n\x0cUpdateParams\x12*.injective.auction.v1beta1.MsgUpdateParams\x1a\x32.injective.auction.v1beta1.MsgUpdateParamsResponseBOZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types'
  _MSGBID.fields_by_name['bid_amount']._options = None
  _MSGBID.fields_by_name['bid_amount']._serialized_options = b'\310\336\037\000'
  _MSGBID._options = None
  _MSGBID._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGBID']._serialized_start=212
  _globals['_MSGBID']._serialized_end=325
  _globals['_MSGBIDRESPONSE']._serialized_start=327
  _globals['_MSGBIDRESPONSE']._serialized_end=343
  _globals['_MSGUPDATEPARAMS']._serialized_start=346
  _globals['_MSGUPDATEPARAMS']._serialized_end=481
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=483
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=508
  _globals['_MSG']._serialized_start=511
  _globals['_MSG']._serialized_end=713
# @@protoc_insertion_point(module_scope)
